<?php
/**
 * Zerif Theme Customizer
 *
 * @package zerif
 */

/**
 * Register Customizer settings
 *
 * @param object $wp_customize Customizer settings.
 */
function wp_themeisle_customize_register( $wp_customize ) {
	/**
	 * Class Zerif_Customize_Alpha_Color_Control
	 */
	class Zerif_Customize_Alpha_Color_Control extends WP_Customize_Control {

		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'alphacolor';

		/**
		 * Control bool
		 *
		 * @var boolean
		 */
		public $palette = true;

		/**
		 * Default color
		 *
		 * @var string
		 */
		public $default = '#3FADD7';

		/**
		 * Function to render the control
		 */
		protected function render() {
			$id    = 'customize-control-' . str_replace( '[', '-', str_replace( ']', '', $this->id ) );
			$class = 'customize-control customize-control-' . $this->type; ?>
			<li id="<?php echo esc_html( $id ); ?>" class="<?php echo esc_html( $class ); ?>">
				<?php
				$this->render_content();
				?>
			</li>
			<?php
		}

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<input type="text" data-palette="<?php echo $this->palette; ?>" data-default-color="<?php echo $this->default; ?>" value="<?php echo intval( $this->value() ); ?>" class="pluto-color-control" <?php $this->link(); ?> />
			</label>
			<?php
		}
	}

	/**
	 * Class Zerif_Video_Sound
	 */
	class Zerif_Video_Sound extends WP_Customize_Control {

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			echo '<label><span class="customize-control-title">' . __( 'Enable video sound?','zerif' ) . '</span></label>';
		}
	}

	/**
	 * Class Zerif_Customizer_Number_Control
	 */
	class Zerif_Customizer_Number_Control extends WP_Customize_Control {

		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'number';

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<input type="number" <?php $this->link(); ?> value="<?php echo intval( $this->value() ); ?>" />
			</label>
			<?php
		}
	}

	/**
	 * Class Zerif_Customize_Textarea_Control
	 */
	class Zerif_Customize_Textarea_Control extends WP_Customize_Control {

		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'textarea';

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<textarea rows="5" id="customize_textarea" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
			<?php
		}
	}

	/**
	 * Class Zerif_Html_Support
	 */
	class Zerif_Html_Support extends WP_Customize_Control {

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			echo __( 'You can insert any HTML code in here, to create links, google maps or anything else.','zerif' );
		}
	}

	/**
	 * Class Zerif_LatestNews
	 */
	class Zerif_LatestNews extends WP_Customize_Control {

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			echo __( 'The main content of this section consists of blog posts.','zerif' );
		}
	}

	/**
	 * Class Zerif_Colors_Panel
	 */
	class Zerif_Colors_Panel extends WP_Customize_Control {

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			echo __( 'To have full control over the colors on homepage sections please visit each section options in Customizer.','zerif' );
		}
	}

	/**
	 * Class Zerif_Intergeo_Panel
	 */
	class Zerif_Intergeo_Panel extends WP_Customize_Control {

		/**
		 * Function to render the controls content
		 */
		public function render_content() {
			echo __( 'You can install <a href="https://wordpress.org/plugins/intergeo-maps/" taget="_blank">WordPress Google Maps Plugin</a> to get more advanced maps option.','zerif' );
		}
	}

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->remove_section( 'colors' );

	require_once( 'class/zerif-pro-info.php' );

	$wp_customize->add_section( 'zerif_pro_theme_info', array(
		'title' => __( 'Theme info', 'zerif' ),
		'priority' => 0,
	) );
	$wp_customize->add_setting( 'zerif_pro_theme_info', array(
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'zerif_pro_sanitize_input',
	) );
	$wp_customize->add_control( new Zerif_Pro_Info( $wp_customize, 'zerif_pro_theme_info', array(
		'section' => 'zerif_pro_theme_info',
		'priority' => 10,
	) ) );

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'custom_logo', array(
				'selector'        => '.navbar-brand',
				'settings'        => 'custom_logo',
				'render_callback' => 'zerif_custom_logo_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bigtitle_title', array(
				'selector'        => '.home-header-wrap .intro-text',
				'settings'        => 'zerif_bigtitle_title',
				'render_callback' => 'zerif_bigtitle_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bigtitle_title_2', array(
				'selector'        => '.home-header-wrap .intro-text',
				'settings'        => 'zerif_bigtitle_title_2',
				'render_callback' => 'zerif_bigtitle_title_2_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bigtitle_redbutton_label', array(
				'selector'        => '.buttons a.red-btn',
				'settings'        => 'zerif_bigtitle_redbutton_label',
				'render_callback' => 'zerif_bigtitle_redbutton_label_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bigtitle_redbutton_label_2', array(
				'selector'        => '.buttons a.red-btn',
				'settings'        => 'zerif_bigtitle_redbutton_label_2',
				'render_callback' => 'zerif_bigtitle_redbutton_label_2_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bigtitle_greenbutton_label', array(
				'selector'        => '.buttons a.green-btn',
				'settings'        => 'zerif_bigtitle_greenbutton_label',
				'render_callback' => 'zerif_bigtitle_greenbutton_label_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ourfocus_title', array(
				'selector'        => '#focus .section-header h2',
				'settings'        => 'zerif_ourfocus_title',
				'render_callback' => 'zerif_ourfocus_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ourfocus_title_2', array(
				'selector'        => '#focus .section-header h2',
				'settings'        => 'zerif_ourfocus_title_2',
				'render_callback' => 'zerif_ourfocus_title_2_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ourfocus_subtitle', array(
				'selector'        => '#focus .section-header h6',
				'settings'        => 'zerif_ourfocus_subtitle',
				'render_callback' => 'zerif_ourfocus_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ourteam_title', array(
				'selector'        => '#team .section-header h2',
				'settings'        => 'zerif_ourteam_title',
				'render_callback' => 'zerif_ourteam_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ourteam_subtitle', array(
				'selector'        => '#team .section-header h6',
				'settings'        => 'zerif_ourteam_subtitle',
				'render_callback' => 'zerif_ourteam_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_title', array(
				'selector'        => '#aboutus .section-header h2',
				'settings'        => 'zerif_aboutus_title',
				'render_callback' => 'zerif_aboutus_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_subtitle', array(
				'selector'        => '#aboutus .section-header h6',
				'settings'        => 'zerif_aboutus_subtitle',
				'render_callback' => 'zerif_aboutus_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_biglefttitle', array(
				'selector'        => '#aboutus .big-intro',
				'settings'        => 'zerif_aboutus_biglefttitle',
				'render_callback' => 'zerif_aboutus_biglefttitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_text', array(
				'selector'        => '#aboutus .text_and_skills p',
				'settings'        => 'zerif_aboutus_text',
				'render_callback' => 'zerif_aboutus_text_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_feature1_title', array(
				'selector'        => '#aboutus .skill_1 label',
				'settings'        => 'zerif_aboutus_feature1_title',
				'render_callback' => 'zerif_aboutus_feature1_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_feature2_title', array(
				'selector'        => '#aboutus .skill_2 label',
				'settings'        => 'zerif_aboutus_feature2_title',
				'render_callback' => 'zerif_aboutus_feature2_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_feature3_title', array(
				'selector'        => '#aboutus .skill_3 label',
				'settings'        => 'zerif_aboutus_feature3_title',
				'render_callback' => 'zerif_aboutus_feature3_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_aboutus_feature4_title', array(
				'selector'        => '#aboutus .skill_4 label',
				'settings'        => 'zerif_aboutus_feature4_title',
				'render_callback' => 'zerif_aboutus_feature4_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_testimonials_title', array(
				'selector'        => '#testimonials .section-header h2',
				'settings'        => 'zerif_testimonials_title',
				'render_callback' => 'zerif_testimonials_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_testimonials_subtitle', array(
				'selector'        => '#testimonials .section-header h6',
				'settings'        => 'zerif_testimonials_subtitle',
				'render_callback' => 'zerif_testimonials_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_contactus_title', array(
				'selector'        => '#contact .section-header h2',
				'render_callback' => 'zerif_contactus_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_contactus_subtitle', array(
				'selector'        => '#contact .section-header h6',
				'render_callback' => 'zerif_contactus_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_contactus_button_label', array(
				'selector'        => '#contact .pirate_forms .contact_submit_wrap',
				'render_callback' => 'zerif_contactus_button_label_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_facebook', array(
				'selector'        => '#footer .social #facebook',
				'settings'        => 'zerif_socials_facebook',
				'render_callback' => 'zerif_socials_facebook_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_twitter', array(
				'selector'        => '#footer .social #twitter',
				'settings'        => 'zerif_socials_twitter',
				'render_callback' => 'zerif_socials_twitter_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_linkedin', array(
				'selector'        => '#footer .social #linkedin',
				'settings'        => 'zerif_socials_linkedin',
				'render_callback' => 'zerif_socials_linkedin_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_behance', array(
				'selector'        => '#footer .social #behance',
				'settings'        => 'zerif_socials_behance',
				'render_callback' => 'zerif_socials_behance_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_dribbble', array(
				'selector'        => '#footer .social #dribbble',
				'settings'        => 'zerif_socials_dribbble',
				'render_callback' => 'zerif_socials_dribbble_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_googleplus', array(
				'selector'        => '#footer .social #google',
				'settings'        => 'zerif_socials_googleplus',
				'render_callback' => 'zerif_socials_googleplus_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_pinterest', array(
				'selector'        => '#footer .social #pinterest',
				'settings'        => 'zerif_socials_pinterest',
				'render_callback' => 'zerif_socials_pinterest_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_tumblr', array(
				'selector'        => '#footer .social #tumblr',
				'settings'        => 'zerif_socials_tumblr',
				'render_callback' => 'zerif_socials_tumblr_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_reddit', array(
				'selector'        => '#footer .social #reddit',
				'settings'        => 'zerif_socials_reddit',
				'render_callback' => 'zerif_socials_reddit_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_youtube', array(
				'selector'        => '#footer .social #youtube',
				'settings'        => 'zerif_socials_youtube',
				'render_callback' => 'zerif_socials_youtube_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_socials_instagram', array(
				'selector'        => '#footer .social #instagram',
				'settings'        => 'zerif_socials_instagram',
				'render_callback' => 'zerif_socials_instagram_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_address', array(
				'selector'        => '.zerif-footer-address',
				'settings'        => 'zerif_address',
				'render_callback' => 'zerif_address_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_email', array(
				'selector'        => '.zerif-footer-email',
				'settings'        => 'zerif_email',
				'render_callback' => 'zerif_email_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_phone', array(
				'selector'        => '.zerif-footer-phone',
				'settings'        => 'zerif_phone',
				'render_callback' => 'zerif_phone_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_address_icon', array(
				'selector'        => '.company-details .icon-top.red-text',
				'settings'        => 'zerif_address_icon',
				'render_callback' => 'zerif_address_icon_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_email_icon', array(
				'selector'        => '.company-details .icon-top.green-text',
				'settings'        => 'zerif_email_icon',
				'render_callback' => 'zerif_email_icon_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_phone_icon', array(
				'selector'        => '.company-details .icon-top.blue-text',
				'settings'        => 'zerif_phone_icon',
				'render_callback' => 'zerif_phone_icon_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bottomribbon_text', array(
				'selector'        => '#ribbon_bottom h3',
				'settings'        => 'zerif_bottomribbon_text',
				'render_callback' => 'zerif_bottomribbon_text_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_bottomribbon_buttonlabel', array(
				'selector'        => '#ribbon_bottom a.btn',
				'settings'        => 'zerif_bottomribbon_buttonlabel',
				'render_callback' => 'zerif_bottomribbon_buttonlabel_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ribbonright_text', array(
				'selector'        => '#ribbon_right h3',
				'settings'        => 'zerif_ribbonright_text',
				'render_callback' => 'zerif_ribbonright_text_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_ribbonright_buttonlabel', array(
				'selector'        => '#ribbon_right a.btn',
				'settings'        => 'zerif_ribbonright_buttonlabel',
				'render_callback' => 'zerif_ribbonright_buttonlabel_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_packages_title', array(
				'selector'        => '#pricingtable h2',
				'settings'        => 'zerif_packages_title',
				'render_callback' => 'zerif_packages_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_packages_subtitle', array(
				'selector'        => '#pricingtable h6',
				'settings'        => 'zerif_packages_subtitle',
				'render_callback' => 'zerif_packages_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_latestnews_title', array(
				'selector'        => '#latestnews h2',
				'settings'        => 'zerif_latestnews_title',
				'render_callback' => 'zerif_latestnews_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_latestnews_subtitle', array(
				'selector'        => '#latestnews h6',
				'settings'        => 'zerif_latestnews_subtitle',
				'render_callback' => 'zerif_latestnews_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_subscribe_title', array(
				'selector'        => '#subscribe h3',
				'settings'        => 'zerif_subscribe_title',
				'render_callback' => 'zerif_subscribe_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_subscribe_subtitle', array(
				'selector'        => '#subscribe div.sub-heading',
				'settings'        => 'zerif_subscribe_subtitle',
				'render_callback' => 'zerif_subscribe_subtitle_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_portofolio_title', array(
				'selector'        => '#works h2',
				'settings'        => 'zerif_portofolio_title',
				'render_callback' => 'zerif_portofolio_title_render_callback',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'zerif_portofolio_subtitle', array(
				'selector'        => '#works h6',
				'settings'        => 'zerif_portofolio_subtitle',
				'render_callback' => 'zerif_portofolio_subtitle_render_callback',
			)
		);

	}

	/**
	 * Render callback for zerif_bigtitle_title
	 *
	 * @return mixed
	 */
	function zerif_bigtitle_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bigtitle_title' ) );
	}
	/**
	 * Render callback for zerif_bigtitle_title_2
	 *
	 * @return mixed
	 */
	function zerif_bigtitle_title_2_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bigtitle_title_2' ) );
	}
	/**
	 * Render callback for zerif_bigtitle_redbutton_label
	 *
	 * @return mixed
	 */
	function zerif_bigtitle_redbutton_label_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bigtitle_redbutton_label' ) );
	}
	/**
	 * Render callback for zerif_bigtitle_redbutton_label_2
	 *
	 * @return mixed
	 */
	function zerif_bigtitle_redbutton_label_2_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bigtitle_redbutton_label_2' ) );
	}
	/**
	 * Render callback for zerif_bigtitle_greenbutton_label
	 *
	 * @return mixed
	 */
	function zerif_bigtitle_greenbutton_label_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bigtitle_greenbutton_label' ) );
	}
	/**
	 * Render callback for zerif_ourfocus_title
	 *
	 * @return mixed
	 */
	function zerif_ourfocus_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ourfocus_title' ) );
	}
	/**
	 * Render callback for zerif_ourfocus_title_2
	 *
	 * @return mixed
	 */
	function zerif_ourfocus_title_2_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ourfocus_title_2' ) );
	}
	/**
	 * Render callback for zerif_ourfocus_subtitle
	 *
	 * @return mixed
	 */
	function zerif_ourfocus_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ourfocus_subtitle' ) );
	}
	/**
	 * Render callback for zerif_ourteam_title
	 *
	 * @return mixed
	 */
	function zerif_ourteam_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ourteam_title' ) );
	}
	/**
	 * Render callback for zerif_ourteam_subtitle
	 *
	 * @return mixed
	 */
	function zerif_ourteam_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ourteam_subtitle' ) );
	}
	/**
	 * Render callback for zerif_aboutus_title
	 *
	 * @return mixed
	 */
	function zerif_aboutus_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_title' ) );
	}
	/**
	 * Render callback for zerif_aboutus_subtitle
	 *
	 * @return mixed
	 */
	function zerif_aboutus_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_subtitle' ) );
	}
	/**
	 * Render callback for zerif_aboutus_biglefttitle
	 *
	 * @return mixed
	 */
	function zerif_aboutus_biglefttitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_biglefttitle' ) );
	}
	/**
	 * Render callback for zerif_aboutus_text
	 *
	 * @return mixed
	 */
	function zerif_aboutus_text_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_text' ) );
	}
	/**
	 * Render callback for zerif_aboutus_feature1_title
	 *
	 * @return mixed
	 */
	function zerif_aboutus_feature1_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_feature1_title' ) );
	}
	/**
	 * Render callback for zerif_aboutus_feature2_title
	 *
	 * @return mixed
	 */
	function zerif_aboutus_feature2_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_feature2_title' ) );
	}
	/**
	 * Render callback for zerif_aboutus_feature3_title
	 *
	 * @return mixed
	 */
	function zerif_aboutus_feature3_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_feature3_title' ) );
	}
	/**
	 * Render callback for zerif_aboutus_feature4_title
	 *
	 * @return mixed
	 */
	function zerif_aboutus_feature4_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_aboutus_feature4_title' ) );
	}
	/**
	 * Render callback for zerif_testimonials_title
	 *
	 * @return mixed
	 */
	function zerif_testimonials_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_testimonials_title' ) );
	}
	/**
	 * Render callback for zerif_testimonials_subtitle
	 *
	 * @return mixed
	 */
	function zerif_testimonials_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_testimonials_subtitle' ) );
	}
	/**
	 * Render callback for zerif_contactus_title
	 *
	 * @return mixed
	 */
	function zerif_contactus_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_contactus_title' ) );
	}
	/**
	 * Render callback for zerif_contactus_button_label
	 */
	function zerif_contactus_button_label_render_callback() {
		?>
		<button id="pirate-forms-contact-submit" name="pirate-forms-contact-submit" class="pirate-forms-submit-button" type="submit">
			<?php echo wp_kses_post( get_theme_mod( 'zerif_contactus_button_label' ) ); ?>
		</button>
		<?php
	}
	/**
	 * Render callback for erif_contactus_subtitle
	 *
	 * @return string
	 */
	function zerif_contactus_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_contactus_subtitle' ) );
	}
	/**
	 * Render callback for zerif_socials_facebook
	 *
	 * @return mixed
	 */
	function zerif_socials_facebook_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_facebook' ) ) . '"><span class="sr-only">' . __( 'Facebook link', 'zerif' ) . '</span> <i class="fa fa-facebook"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_twitter
	 *
	 * @return mixed
	 */
	function zerif_socials_twitter_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_twitter' ) ) . '"><span class="sr-only">' . __( 'Twitter link', 'zerif' ) . '</span> <i class="fa fa-twitter"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_linkedin
	 *
	 * @return mixed
	 */
	function zerif_socials_linkedin_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_linkedin' ) ) . '"><span class="sr-only">' . __( 'Linkedin link', 'zerif' ) . '</span> <i class="fa fa-linkedin"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_behance
	 *
	 * @return mixed
	 */
	function zerif_socials_behance_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_behance' ) ) . '"><span class="sr-only">' . __( 'Behance link', 'zerif' ) . '</span> <i class="fa fa-behance"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_dribbble
	 *
	 * @return mixed
	 */
	function zerif_socials_dribbble_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_dribbble' ) ) . '"><span class="sr-only">' . __( 'Dribble link', 'zerif' ) . '</span> <i class="fa fa-dribbble"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_googleplus
	 *
	 * @return mixed
	 */
	function zerif_socials_googleplus_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_googleplus' ) ) . '"><span class="sr-only">' . __( 'Google Plus link', 'zerif' ) . '</span> <i class="fa fa-google"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_pinterest
	 *
	 * @return mixed
	 */
	function zerif_socials_pinterest_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_pinterest' ) ) . '"><span class="sr-only">' . __( 'Pinterest link', 'zerif' ) . '</span> <i class="fa fa-pinterest"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_tumblr
	 *
	 * @return mixed
	 */
	function zerif_socials_tumblr_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_tumblr' ) ) . '"><span class="sr-only">' . __( 'Tumblr link', 'zerif' ) . '</span> <i class="fa fa-tumblr"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_reedit
	 *
	 * @return mixed
	 */
	function zerif_socials_reddit_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_reddit_tumblr' ) ) . '"><span class="sr-only">' . __( 'Reddit link', 'zerif' ) . '</span> <i class="fa fa-reddit"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_youtube
	 *
	 * @return mixed
	 */
	function zerif_socials_youtube_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_youtube_tumblr' ) ) . '"><span class="sr-only">' . __( 'Youtube link', 'zerif' ) . '</span> <i class="fa fa-youtube"></i></a>';
	}
	/**
	 * Render callback for zerif_socials_instagram
	 *
	 * @return mixed
	 */
	function zerif_socials_instagram_render_callback() {
		return '<a href="' . esc_url( get_theme_mod( 'zerif_socials_instagram' ) ) . '"><span class="sr-only">' . __( 'Instagram link', 'zerif' ) . '</span> <i class="fa fa-instagram"></i></a>';
	}
	/**
	 * Render callback for zerif_address
	 *
	 * @return mixed
	 */
	function zerif_address_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_address' ) );
	}
	/**
	 * Render callback for zerif_email
	 *
	 * @return mixed
	 */
	function zerif_email_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_email' ) );
	}
	/**
	 * Render callback for zerif_phone
	 *
	 * @return mixed
	 */
	function zerif_phone_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_phone' ) );
	}
	/**
	 * Render callback for zerif_address_icon
	 *
	 * @return mixed
	 */
	function zerif_address_icon_render_callback() {
		return '<img src="' . esc_url( get_theme_mod( 'zerif_address_icon' ) ) . '">';
	}
	/**
	 * Render callback for zerif_email_icon
	 *
	 * @return mixed
	 */
	function zerif_email_icon_render_callback() {
		return '<img src="' . esc_url( get_theme_mod( 'zerif_email_icon' ) ) . '">';
	}
	/**
	 * Render callback for zerif_phone_icon
	 *
	 * @return mixed
	 */
	function zerif_phone_icon_render_callback() {
		return '<img src="' . esc_url( get_theme_mod( 'zerif_phone_icon' ) ) . '">';
	}
	/**
	 * Render callback for zerif_bottomribbon_text
	 *
	 * @return mixed
	 */
	function zerif_bottomribbon_text_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bottomribbon_text' ) );
	}
	/**
	 * Render callback for zerif_bottomribbon_buttonlabel
	 *
	 * @return mixed
	 */
	function zerif_bottomribbon_buttonlabel_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_bottomribbon_buttonlabel' ) );
	}
	/**
	 * Render callback for zerif_ribbonright_text
	 *
	 * @return mixed
	 */
	function zerif_ribbonright_text_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ribbonright_text' ) );
	}
	/**
	 * Render callback for zerif_ribbonright_buttonlabel
	 *
	 * @return mixed
	 */
	function zerif_ribbonright_buttonlabel_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_ribbonright_buttonlabel' ) );
	}
	/**
	 * Render callback for zerif_packages_title
	 *
	 * @return mixed
	 */
	function zerif_packages_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_packages_title' ) );
	}
	/**
	 * Render callback for zerif_packages_subtitle
	 *
	 * @return mixed
	 */
	function zerif_packages_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_packages_subtitle' ) );
	}
	/**
	 * Render callback for zerif_latestnews_title
	 *
	 * @return mixed
	 */
	function zerif_latestnews_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_latestnews_title' ) );
	}
	/**
	 * Render callback for zerif_latestnews_subtitle
	 *
	 * @return mixed
	 */
	function zerif_latestnews_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_latestnews_subtitle' ) );
	}
	/**
	 * Render callback for zerif_subscribe_title
	 *
	 * @return mixed
	 */
	function zerif_subscribe_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_subscribe_title' ) );
	}
	/**
	 * Render callback for zerif_subscribe_subtitle
	 *
	 * @return mixed
	 */
	function zerif_subscribe_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_subscribe_subtitle' ) );
	}
	/**
	 * Render callback for zerif_portofolio_title
	 *
	 * @return mixed
	 */
	function zerif_portofolio_title_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_portofolio_title' ) );
	}
	/**
	 * Render callback for zerif_portofolio_subtitle
	 *
	 * @return mixed
	 */
	function zerif_portofolio_subtitle_render_callback() {
		return wp_kses_post( get_theme_mod( 'zerif_portofolio_subtitle' ) );
	}

	/**
	 * ORDER
	 */

	$wp_customize->add_section( 'zerif_order_section' , array(
		'title'       => __( 'Sections order', 'zerif' ),
		'description' => __( 'Here is where you can rearrange the homepage sections.','zerif' ),
		'priority'    => 29,
	) );

	/* section 1 */
	$wp_customize->add_setting( 'section1', array(
		'default' => 'our_focus',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section1', array(
		'type' => 'select',
		'label' => '1st section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 1,
	) );

	/* section 2 */
	$wp_customize->add_setting( 'section2', array(
		'default' => 'bottom_ribbon',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section2', array(
		'type' => 'select',
		'label' => '2nd section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 2,
	) );

	/* section 3 */
	$wp_customize->add_setting( 'section3', array(
		'default' => 'portofolio',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section3', array(
		'type' => 'select',
		'label' => '3rd section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 3,
	) );

	/* section 4 */
	$wp_customize->add_setting( 'section4', array(
		'default' => 'about_us',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section4', array(
		'type' => 'select',
		'label' => '4rt section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 4,
	) );

	/* section 5 */
	$wp_customize->add_setting( 'section5', array(
		'default' => 'our_team',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section5', array(
		'type' => 'select',
		'label' => '5th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 5,
	) );

	/* section 6 */
	$wp_customize->add_setting( 'section6', array(
		'default' => 'testimonials',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section6', array(
		'type' => 'select',
		'label' => '6th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),

		),
		'priority' => 6,
	) );

	/* section 7 */
	$wp_customize->add_setting( 'section7', array(
		'default' => 'right_ribbon',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section7', array(
		'type' => 'select',
		'label' => '7th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),

		),
		'priority' => 7,
	) );

	/* section 8 */
	$wp_customize->add_setting( 'section8', array(
		'default' => 'contact_us',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section8', array(
		'type' => 'select',
		'label' => '8th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 8,
	) );

	/* section 9 */
	$wp_customize->add_setting( 'section9', array(
		'default' => 'map',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section9', array(
		'type' => 'select',
		'label' => '9th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 9,
	) );

	/* section 10 */
	$wp_customize->add_setting( 'section10', array(
		'default' => 'packages',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section10', array(
		'type' => 'select',
		'label' => '10th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 10,
	) );

	/* section 11 */
	$wp_customize->add_setting( 'section11', array(
		'default' => 'subscribe',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section11', array(
		'type' => 'select',
		'label' => '11th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 11,
	) );

	/* section 12 */
	$wp_customize->add_setting( 'section12', array(
		'default' => 'latest_news',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section12', array(
		'type' => 'select',
		'label' => '12th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),
		),
		'priority' => 12,
	) );

	/* section 13 */
	$wp_customize->add_setting( 'section13', array(
		'default' => 'shortcodes',
		'sanitize_callback' => 'zerif_sanitize_section_name',
	) );

	$wp_customize->add_control( 'section13', array(
		'type' => 'select',
		'label' => '13th section',
		'section' => 'zerif_order_section',
		'choices' => array(
			'our_focus' => __( 'Our focus','zerif' ),
			'portofolio' => __( 'Portfolio','zerif' ),
			'about_us' => __( 'About us','zerif' ),
			'our_team' => __( 'Our team','zerif' ),
			'testimonials' => __( 'Testimonials','zerif' ),
			'bottom_ribbon' => __( 'Bottom ribbon','zerif' ),
			'right_ribbon' => __( 'Right ribbon','zerif' ),
			'contact_us' => __( 'Contact us','zerif' ),
			'packages' => __( ' Packages','zerif' ),
			'map' => __( 'Google map','zerif' ),
			'subscribe' => __( 'Subscribe','zerif' ),
			'latest_news' => __( 'Latest news','zerif' ),
			'shortcodes' => __( 'Shortcodes','zerif' ),

		),
		'priority' => 13,
	) );

	/**
	 * COLORS OPTIONS
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_1', array(
			'priority' => 30,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Colors', 'zerif' ),
		));

		/* COLORS HOMEPAGE */

		$wp_customize->add_section( 'zerif_hp_color_section', array(
			'title' => __( 'Homepage sections', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_1',
		));

		$wp_customize->add_setting( 'zerif_hp_color_section' );

		$wp_customize->add_control( new Zerif_Colors_Panel( $wp_customize, 'zerif_hp_color_section', array(
			'section' => 'zerif_hp_color_section',
		)));

		/* COLORS FOOTER */

		$wp_customize->add_section( 'zerif_footer_color_section', array(
			'title' => __( 'Footer colors', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_1',
		));

		/* zerif_footer_background */
		$wp_customize->add_setting( 'zerif_footer_background', array(
			'default' => apply_filters( 'zerif_footer_background_filter', '#272727' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_background', array(
			'label' => __( 'Footer background color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 1,
		)));

		/* zerif_footer_socials_background */
		$wp_customize->add_setting( 'zerif_footer_socials_background', array(
			'default' => apply_filters( 'zerif_footer_socials_background_filter', '#171717' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials_background', array(
			'label' => __( 'Footer socials background color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 2,
		)));

		/* zerif_footer_text_color */
		$wp_customize->add_setting( 'zerif_footer_text_color', array(
			'default' => apply_filters( 'zerif_footer_text_color_filter', '#939393' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_text_color', array(
			'label' => __( 'Footer text color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 3,
		)));

		/* zerif_footer_text_color_hover */
		$wp_customize->add_setting( 'zerif_footer_text_color_hover', array(
			'default' => apply_filters( 'zerif_footer_text_color_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_text_color_hover', array(
			'label' => __( 'Footer text color - hover', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 4,
		)));

		/* zerif_footer_socials */
		$wp_customize->add_setting( 'zerif_footer_socials', array(
			'default' => apply_filters( 'zerif_footer_socials_filter', '#939393' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials', array(
			'label' => __( 'Footer social icons color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 5,
		)));

		/* zerif_footer_socials_hover */
		$wp_customize->add_setting( 'zerif_footer_socials_hover', array(
			'default' => apply_filters( 'zerif_footer_socials_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials_hover', array(
			'label' => __( 'Footer socials icons color - hover', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 6,
		)));

		/* zerif_footer_widgets_title */
		$wp_customize->add_setting( 'zerif_footer_widgets_title', array(
			'default' => apply_filters( 'zerif_footer_widgets_title_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_widgets_title', array(
			'label' => __( 'Footer widgets title color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 7,
		)));

		/* zerif_footer_widgets_title_border_bottom */
		$wp_customize->add_setting( 'zerif_footer_widgets_title_border_bottom', array(
			'default' => apply_filters( 'zerif_footer_widgets_title_border_bottom_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_widgets_title_border_bottom', array(
			'label' => __( 'Footer widgets title bottom border color', 'zerif' ),
			'section' => 'zerif_footer_color_section',
			'priority' => 8,
		)));

		/* COLORS FOOTER */

		$wp_customize->add_section( 'zerif_general_color_section', array(
			'title' => __( 'General colors', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_1',
		));

		$wp_customize->add_setting( 'zerif_menu_item_color', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_menu_item_color', array(
			'label' => __( 'Menu item color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 1,
		)));

		$wp_customize->add_setting( 'zerif_menu_item_hover_color', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_menu_item_hover_color', array(
			'label' => __( 'Menu item color hover', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 2,
		)));

		/* zerif_background_color */
		$wp_customize->add_setting( 'zerif_background_color', array(
			'default' => apply_filters( 'zerif_background_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_background_color', array(
			'label' => __( 'Background color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 3,
		)));

		/* zerif_navbar_color */
		$wp_customize->add_setting( 'zerif_navbar_color', array(
			'default' => apply_filters( 'zerif_navbar_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_navbar_color', array(
			'label' => __( 'Navbar background color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 4,
		)));

		/* zerif_titles_color */
		$wp_customize->add_setting( 'zerif_titles_color', array(
			'default' => apply_filters( 'zerif_titles_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_titles_color', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 5,
		)));

		/* zerif_titles_bottomborder_color */
		$wp_customize->add_setting( 'zerif_titles_bottomborder_color', array(
			'default' => apply_filters( 'zerif_titles_bottomborder_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_titles_bottomborder_color', array(
			'label' => __( 'Titles bottom border color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 6,
		)));

		/* zerif_texts_color */
		$wp_customize->add_setting( 'zerif_texts_color', array(
			'default' => apply_filters( 'zerif_texts_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_texts_color', array(
			'label' => __( 'Text color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 7,
		)));

		/* zerif_links_color */
		$wp_customize->add_setting( 'zerif_links_color', array(
			'default' => apply_filters( 'zerif_links_color_filter', '#808080' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_links_color', array(
			'label' => __( 'Links color', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 8,
		)));

		/* zerif_links_color_hover */
		$wp_customize->add_setting( 'zerif_links_color_hover', array(
			'default' => apply_filters( 'zerif_links_color_hover_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_links_color_hover', array(
			'label' => __( 'Links color hover', 'zerif' ),
			'section' => 'zerif_general_color_section',
			'priority' => 9,
		)));

		/* COLORS BUTTONS */

		$wp_customize->add_section( 'zerif_buttons_color_section', array(
			'title' => __( 'Buttons colors', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_1',
		));

		/* zerif_buttons_background_color */
		$wp_customize->add_setting( 'zerif_buttons_background_color', array(
			'default' => apply_filters( 'zerif_buttons_background_color_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_background_color', array(
			'label' => __( 'Buttons background color', 'zerif' ),
			'section' => 'zerif_buttons_color_section',
			'priority' => 1,
		)));

		/* zerif_buttons_background_color_hover */
		$wp_customize->add_setting( 'zerif_buttons_background_color_hover', array(
			'default' => apply_filters( 'zerif_buttons_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_background_color_hover', array(
			'label' => __( 'Buttons background color - hover', 'zerif' ),
			'section' => 'zerif_buttons_color_section',
			'priority' => 2,
		)));

		/* zerif_buttons_text_color */
		$wp_customize->add_setting( 'zerif_buttons_text_color', array(
			'default' => apply_filters( 'zerif_buttons_text_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_text_color', array(
			'label' => __( 'Buttons text color', 'zerif' ),
			'section' => 'zerif_buttons_color_section',
			'priority' => 3,
		)));

	} else { /* Older versions of WordPress */

		$wp_customize->add_section( 'zerif_color_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 30,
			'description' => __( 'Zerif theme colors', 'zerif' ),
		));

		/* zerif_footer_background */
		$wp_customize->add_setting( 'zerif_footer_background', array(
			'default' => apply_filters( 'zerif_footer_background_filter', '#272727' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_background', array(
			'label' => __( 'Footer background color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 1,
		)));

		/* zerif_footer_socials_background */
		$wp_customize->add_setting( 'zerif_footer_socials_background', array(
			'default' => apply_filters( 'zerif_footer_socials_background_filter', '#171717' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials_background', array(
			'label' => __( 'Footer socials background color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 2,
		)));

		/* zerif_footer_text_color */
		$wp_customize->add_setting( 'zerif_footer_text_color', array(
			'default' => apply_filters( 'zerif_footer_text_color_filter', '#939393' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_text_color', array(
			'label' => __( 'Footer text color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 3,
		)));

		/* zerif_footer_text_color_hover */
		$wp_customize->add_setting( 'zerif_footer_text_color_hover', array(
			'default' => apply_filters( 'zerif_footer_text_color_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_text_color_hover', array(
			'label' => __( 'Footer text color - hover', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 4,
		)));

		/* zerif_footer_socials */
		$wp_customize->add_setting( 'zerif_footer_socials', array(
			'default' => apply_filters( 'zerif_footer_socials_filter', '#939393' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials', array(
			'label' => __( 'Footer social icons color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 5,
		)));

		/* zerif_footer_socials_hover */
		$wp_customize->add_setting( 'zerif_footer_socials_hover', array(
			'default' => apply_filters( 'zerif_footer_socials_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_socials_hover', array(
			'label' => __( 'Footer socials icons color - hover', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 6,
		)));

		/* zerif_footer_widgets_title */
		$wp_customize->add_setting( 'zerif_footer_widgets_title', array(
			'default' => apply_filters( 'zerif_footer_widgets_title_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_widgets_title', array(
			'label' => __( 'Footer widgets title color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 7,
		)));

		/* zerif_footer_widgets_title_border_bottom */
		$wp_customize->add_setting( 'zerif_footer_widgets_title_border_bottom', array(
			'default' => apply_filters( 'zerif_footer_widgets_title_border_bottom_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_footer_widgets_title_border_bottom', array(
			'label' => __( 'Footer widgets title bottom border color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 8,
		)));

		/* zerif_background_color */
		$wp_customize->add_setting( 'zerif_background_color', array(
			'default' => apply_filters( 'zerif_background_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_background_color', array(
			'label' => __( 'Background color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 9,
		)));

		/* zerif_navbar_color */
		$wp_customize->add_setting( 'zerif_navbar_color', array(
			'default' => apply_filters( 'zerif_navbar_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_navbar_color', array(
			'label' => __( 'Navbar background color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 10,
		)));

		/* zerif_titles_color */
		$wp_customize->add_setting( 'zerif_titles_color', array(
			'default' => apply_filters( 'zerif_titles_color_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_titles_color', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 11,
		)));

		/* zerif_titles_bottomborder_color */
		$wp_customize->add_setting( 'zerif_titles_bottomborder_color', array(
			'default' => apply_filters( 'zerif_titles_bottomborder_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_titles_bottomborder_color', array(
			'label' => __( 'Titles bottom border color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 12,
		)));

		/* zerif_texts_color */
		$wp_customize->add_setting( 'zerif_texts_color', array(
			'default' => apply_filters( 'zerif_texts_color_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_texts_color', array(
			'label' => __( 'Text color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 13,
		)));

		/* zerif_links_color */
		$wp_customize->add_setting( 'zerif_links_color', array(
			'default' => apply_filters( 'zerif_links_color_filter', '#808080' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_links_color', array(
			'label' => __( 'Links color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 14,
		)));

		/* zerif_links_color_hover */
		$wp_customize->add_setting( 'zerif_links_color_hover', array(
			'default' => apply_filters( 'zerif_links_color_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_links_color_hover', array(
			'label' => __( 'Links color hover', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 15,
		)));

		/* zerif_buttons_background_color */
		$wp_customize->add_setting( 'zerif_buttons_background_color', array(
			'default' => apply_filters( 'zerif_buttons_background_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_background_color', array(
			'label' => __( 'Buttons background color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 16,
		)));

		/* zerif_buttons_background_color_hover */
		$wp_customize->add_setting( 'zerif_buttons_background_color_hover', array(
			'default' => apply_filters( 'zerif_buttons_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_background_color_hover', array(
			'label' => __( 'Buttons background color - hover', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 17,
		)));

		/* zerif_buttons_text_color */
		$wp_customize->add_setting( 'zerif_buttons_text_color', array(
			'default' => apply_filters( 'zerif_buttons_text_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_buttons_text_color', array(
			'label' => __( 'Buttons text color', 'zerif' ),
			'section' => 'zerif_color_section',
			'priority' => 18,
		)));

	}

	/**
	 * GENERAL OPTIONS
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_2', array(
			'priority' => 31,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'General options', 'zerif' ),
		));

		$wp_customize->add_section( 'zerif_general_section', array(
			'title' => __( 'General options', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_2',
		));

		/* safe font */
		$wp_customize->add_setting( 'zerif_use_safe_font', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_use_safe_font', array(
			'type' => 'checkbox',
			'label' => __( 'Use safe font?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 1,
		));

		/* zerif_disable_preloader */
		$wp_customize->add_setting( 'zerif_disable_preloader', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_disable_preloader', array(
			'type' => 'checkbox',
			'label' => __( 'Disable preloader?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 2,
		));

		/* Disable smooth scroll */
		$wp_customize->add_setting( 'zerif_disable_smooth_scroll', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_disable_smooth_scroll', array(
			'type' => 'checkbox',
			'label' => __( 'Disable smooth scroll?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 3,
		));

		$wp_customize->add_setting( 'zerif_accessibility', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_accessibility', array(
			'type' => 'checkbox',
			'label' => __( 'Enable accessibility?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 4,
		));

		/* zerif_copyright */
		$wp_customize->add_setting( 'zerif_copyright', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_copyright', array(
			'label' => __( 'Footer Copyright', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 6,
		));

		/* zerif_google_anaytics */
		$wp_customize->add_setting( 'zerif_google_anaytics', array(
			'sanitize_callback' => 'force_balance_tags',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_google_anaytics', array(
			'label' => __( 'Google analytics code', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 7,
		)));

		/* Change the template to full width for page.php */
		$wp_customize->add_setting( 'zerif_change_to_full_width', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_change_to_full_width', array(
			'type' => 'checkbox',
			'label' => __( 'Change the template to Full width for all the pages?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 8,
		));

		/* Display thumbnail on single.php */
		$wp_customize->add_setting( 'zerif_add_thumbnail_posts', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_add_thumbnail_posts', array(
			'type' => 'checkbox',
			'label' => __( 'Display Featured Image in posts?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 9,
		));

		/* Display thumbnail on page.php */
		$wp_customize->add_setting( 'zerif_add_thumbnail_pages', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_add_thumbnail_pages', array(
			'type' => 'checkbox',
			'label' => __( 'Display Featured Image in pages?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 10,
		));

		$wp_customize->add_section( 'zerif_footer_section', array(
			'title' => __( 'Footer sections', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_2',
		));

		$wp_customize->add_setting( 'zerif_html_note' );

		$wp_customize->add_control( new Zerif_Html_Support( $wp_customize, 'zerif_html_note', array(
			'section' => 'zerif_footer_section',
			'priority' => '1',
		)));

		/* email - ICON */
		$wp_customize->add_setting( 'zerif_email_icon', array(
			'default' => get_template_directory_uri() . '/images/envelope4-green.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_email_icon', array(
			'label' => __( 'Email section - icon', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 2,
		)));

		/* email */
		$wp_customize->add_setting( 'zerif_email', array(
			'default' => '<a href="mailto:contact@site.com">contact@site.com</a>',
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_email', array(
			'label' => __( 'Email', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 3,
		)));

		/* phone number - ICON */
		$wp_customize->add_setting( 'zerif_phone_icon', array(
			'default' => get_template_directory_uri() . '/images/telephone65-blue.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_phone_icon', array(
			'label' => __( 'Phone number section - icon', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 4,
		)));

		/* phone number */
		$wp_customize->add_setting( 'zerif_phone', array(
			'default' => '<a href="tel:0 332 548 954">0 332 548 954</a>',
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_phone', array(
			'label' => __( 'Phone number', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 5,
		)));

		/* address - ICON */
		$wp_customize->add_setting( 'zerif_address_icon', array(
			'default' => get_template_directory_uri() . '/images/map25-redish.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_address_icon', array(
			'label' => __( 'Address section - icon', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 6,
		)));

		/* address */
		$wp_customize->add_setting( 'zerif_address', array(
			'default' => __( 'Company address', 'zerif' ),
			'sanitize_callback' => 'zerif_sanitize_input',
		));
		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_address', array(
			'label' => __( 'Address', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 7,
		)));

		$wp_customize->add_section( 'zerif_general_socials_section', array(
			'title' => __( 'Socials options', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_2',
		));

		/* facebook */
		$wp_customize->add_setting( 'zerif_socials_facebook', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_facebook', array(
			'label' => __( 'Facebook link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 1,
		));

		/* twitter */
		$wp_customize->add_setting( 'zerif_socials_twitter', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_twitter', array(
			'label' => __( 'Twitter link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 2,
		));

		/* linkedin */
		$wp_customize->add_setting( 'zerif_socials_linkedin', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_linkedin', array(
			'label' => __( 'Linkedin link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 3,
		));

		/* behance */
		$wp_customize->add_setting( 'zerif_socials_behance', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_behance', array(
			'label' => __( 'Behance link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 4,
		));

		/* dribbble */
		$wp_customize->add_setting( 'zerif_socials_dribbble', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_dribbble', array(
			'label' => __( 'Dribbble link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 5,
		));

		/* Google+ */
		$wp_customize->add_setting( 'zerif_socials_googleplus', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_googleplus', array(
			'label' => __( 'Google+ link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 6,
		));

		/* Pinterest */
		$wp_customize->add_setting( 'zerif_socials_pinterest', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_pinterest', array(
			'label' => __( 'Pinterest link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 7,
		));

		/* Tumblr */
		$wp_customize->add_setting( 'zerif_socials_tumblr', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_tumblr', array(
			'label' => __( 'Tumblr link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 8,
		));

		/* Reddit */
		$wp_customize->add_setting( 'zerif_socials_reddit', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_reddit', array(
			'label' => __( 'Reddit link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 9,
		));

		/* YouTube */
		$wp_customize->add_setting( 'zerif_socials_youtube', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_youtube', array(
			'label' => __( 'YouTube link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 10,
		));

		/* Instagram */
		$wp_customize->add_setting( 'zerif_socials_instagram', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_socials_instagram', array(
			'label' => __( 'Instagram link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 11,
		));

	} else {

		$wp_customize->add_section( 'zerif_general_section', array(
			'title' => __( 'General options', 'zerif' ),
			'priority' => 31,
			'description' => __( 'Zerif theme general options', 'zerif' ),
		));

		/* safe font */
		$wp_customize->add_setting( 'zerif_use_safe_font', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_use_safe_font', array(
			'type' => 'checkbox',
			'label' => __( 'Use safe font?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 1,
		));

		/* COPYRIGHT */

		$wp_customize->add_setting( 'zerif_copyright', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_copyright', array(
			'label' => __( 'Copyright', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 3,
		));

		/* Google analytics */

		$wp_customize->add_setting( 'zerif_google_anaytics', array(
			'sanitize_callback' => 'force_balance_tags',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_google_anaytics', array(
			'label' => __( 'Google analytics code', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 4,
		)));

		/* Disable preloader */
		$wp_customize->add_setting( 'zerif_disable_preloader', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_disable_preloader', array(
			'type' => 'checkbox',
			'label' => __( 'Disable preloader?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 5,
		));

		/* Disable smooth scroll */
		$wp_customize->add_setting( 'zerif_disable_smooth_scroll', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_disable_smooth_scroll', array(
			'type' => 'checkbox',
			'label' => __( 'Disable smooth scroll?', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 6,
		));

		$wp_customize->add_setting( 'zerif_html_note' );

		$wp_customize->add_control( new Zerif_Html_Support( $wp_customize, 'zerif_html_note', array(
			'section' => 'zerif_footer_section',
			'priority' => 7,
		)));

		/* Change the template to full width for page.php */
		$wp_customize->add_setting( 'zerif_change_to_full_width', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_change_to_full_width', array(
			'type' => 'checkbox',
			'label' => __( 'Change the template to Full width for all the pages?', 'zerif' ),
			'section' => 'zerif_footer_section',
			'priority' => 8,
		));

		/* email - ICON */
		$wp_customize->add_setting( 'zerif_email_icon', array(
			'default' => get_template_directory_uri() . '/images/envelope4-green.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_email_icon', array(
			'label' => __( 'Email section - icon', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 9,
		)));

		/* email */
		$wp_customize->add_setting( 'zerif_email', array(
			'default' => __( 'Company email', 'zerif' ),
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_email', array(
			'label' => __( 'Email', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 10,
		)));

		/* phone number - ICON */
		$wp_customize->add_setting( 'zerif_phone_icon', array(
			'default' => get_template_directory_uri() . '/images/telephone65-blue.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_phone_icon', array(
			'label' => __( 'Phone number section - icon', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 11,
		)));

		/* phone number */
		$wp_customize->add_setting( 'zerif_phone', array(
			'default' => __( 'Phone number', 'zerif' ),
			'sanitize_callback' => 'zerif_sanitize_input',
		));
		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_phone', array(
			'label' => __( 'Phone number', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 12,
		)));

		/* address - ICON */
		$wp_customize->add_setting( 'zerif_address_icon', array(
			'default' => get_template_directory_uri() . '/images/map25-redish.png',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_address_icon', array(
			'label' => __( 'Address section - icon', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 13,
		)));

		/* address */

		$wp_customize->add_setting( 'zerif_address', array(
			'default' => __( 'Company address', 'zerif' ),
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_address', array(
			'label' => __( 'Address', 'zerif' ),
			'section' => 'zerif_general_section',
			'priority' => 14,
		)));

		$wp_customize->add_section( 'zerif_general_socials_section', array(
			'title' => __( 'Socials options', 'zerif' ),
			'priority' => 40,
		));

		/* facebook */
		$wp_customize->add_setting( 'zerif_socials_facebook', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_socials_facebook', array(
			'label' => __( 'Facebook link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 1,
		));

		/* twitter */
		$wp_customize->add_setting( 'zerif_socials_twitter', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_socials_twitter', array(
			'label' => __( 'Twitter link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 2,
		));

		/* linkedin */
		$wp_customize->add_setting( 'zerif_socials_linkedin', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_socials_linkedin', array(
			'label' => __( 'Linkedin link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 3,
		));

		/* behance */
		$wp_customize->add_setting( 'zerif_socials_behance', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_socials_behance', array(
			'label' => __( 'Behance link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 4,
		));

		/* dribbble */
		$wp_customize->add_setting( 'zerif_socials_dribbble', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_socials_dribbble', array(
			'label' => __( 'Dribbble link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 5,
		));

		/* Google+ */
		$wp_customize->add_setting( 'zerif_socials_googleplus', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_googleplus', array(
			'label' => __( 'Google+ link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 6,
		));

		/* Pinterest */
		$wp_customize->add_setting( 'zerif_socials_pinterest', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_pinterest', array(
			'label' => __( 'Pinterest link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 7,
		));

		/* Tumblr */
		$wp_customize->add_setting( 'zerif_socials_tumblr', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_tumblr', array(
			'label' => __( 'Tumblr link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 8,
		));

		/* Reddit */
		$wp_customize->add_setting( 'zerif_socials_reddit', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_reddit', array(
			'label' => __( 'Reddit link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 9,
		));

		/* YouTube */
		$wp_customize->add_setting( 'zerif_socials_youtube', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_youtube', array(
			'label' => __( 'YouTube link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 10,
		));

		/* Instagram */
		$wp_customize->add_setting( 'zerif_socials_instagram', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_socials_instagram', array(
			'label' => __( 'Instagram link', 'zerif' ),
			'section' => 'zerif_general_socials_section',
			'priority' => 11,
		));

	}

	/**
	 * BACKGROUND
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel(
			'panel_background',
			array(
				'priority' => 32,
				'capability' => 'edit_theme_options',
				'theme_supports' => '',
				'title' => __( 'Background', 'zerif' ),
			)
		);

		/* Background settings */
		$wp_customize->add_section( 'zerif_background_settings_section', array(
			'title' => __( 'Background settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_background',
		));

		$wp_customize->add_setting( 'zerif_background_settings', array(
			'sanitize_callback' => 'zerif_sanitize_background_type',
		));

		$wp_customize->add_control( 'zerif_background_settings', array(
			'type' => 'radio',
			'label' => __( 'Type of background', 'zerif' ),
			'description' => __( 'Select the type of background you want. <b>Make sure you also set up the images/video in their corresponding places, down below.</b>', 'zerif' ),
			'section' => 'zerif_background_settings_section',
			'choices' => array(
				'zerif-background-image' => __( 'Background image', 'zerif' ),
				'zerif-background-slider' => __( 'Background slider', 'zerif' ),
				'zerif-background-video' => __( 'Background video', 'zerif' ),
			),
			'priority' => 1,
		));

		/* Background image */
		$wp_customize->get_section( 'background_image' )->panel = 'panel_background';
		$wp_customize->get_section( 'background_image' )->priority = 2;

		/* Background slider */
		$wp_customize->add_section( 'zerif_background_slider_section', array(
			'title' => __( 'Background slider', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_background',
		));

		/* slider image 1 */
		$wp_customize->add_setting( 'zerif_bgslider_1', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_1', array(
			'label' => __( 'Image 1', 'zerif' ),
			'section' => 'zerif_background_slider_section',
			'priority' => 1,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_1', array(
			'default' => 'top',
			'sanitize_callback' => 'zerif_sanitize_position',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_1', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 2,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_1', array(
			'default' => 'left',
			'sanitize_callback' => 'zerif_sanitize_horizontal',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_1', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 3,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_1', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_1', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 4,
		));

		/* slider image 2 */
		$wp_customize->add_setting( 'zerif_bgslider_2', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_2', array(
			'label' => __( 'Image 2', 'zerif' ),
			'section' => 'zerif_background_slider_section',
			'priority' => 5,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_2', array(
			'default' => 'top',
			'sanitize_callback' => 'zerif_sanitize_position',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_2', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 6,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_2', array(
			'default' => 'left',
			'sanitize_callback' => 'zerif_sanitize_horizontal',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_2', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 7,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_2', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_2', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 8,
		));

		/* slider image 3 */
		$wp_customize->add_setting( 'zerif_bgslider_3', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_3', array(
			'label' => __( 'Image 3', 'zerif' ),
			'section' => 'zerif_background_slider_section',
			'priority' => 9,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_3', array(
			'sanitize_callback' => 'zerif_sanitize_position',
			'default' => 'top',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_3', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 10,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_3', array(
			'sanitize_callback' => 'zerif_sanitize_horizontal',
			'default' => 'left',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_3', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 11,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_3', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_3', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_background_slider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 12,
		));

		/* Video Background */
		$wp_customize->add_section( 'zerif_background_video_section', array(
			'title' => __( 'Background Video', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_background',
		));

		/* Video */
		$wp_customize->add_setting( 'zerif_background_video', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Upload_Control( $wp_customize, 'zerif_background_video', array(
			'label' => __( 'Video file', 'zerif' ),
			'description' => __( 'mp4 format file <br/> Note: Video background doesn\'t work on mobile devices.', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 1,
		)));

		/* Thumbnail */
		$wp_customize->add_setting( 'zerif_background_video_thumbnail', array(
			'sanitize_callback' => 'esc_url',
		));
		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_background_video_thumbnail', array(
			'label' => __( 'Video thumbnail', 'zerif' ),
			'description' => __( 'This image will appear while the video is downloading. If this is not included, the first frame of the video will be used instead.', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 2,
		)));

		/* zerif_enable_video_sound_title */
		$wp_customize->add_setting( 'zerif_enable_video_sound_title', array(
			'sanitize_callback' => 'zerif_sanitize_pro_version',
		));
		$wp_customize->add_control( new Zerif_Video_Sound( $wp_customize, 'zerif_enable_video_sound_title', array(
			'section' => 'zerif_background_video_section',
			'priority' => 3,
		)));

		/* zerif_enable_video_sound */
		$wp_customize->add_setting( 'zerif_enable_video_sound', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_enable_video_sound', array(
			'type' => 'checkbox',
			'label' => __( 'Enable sound', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 4,
		));

	} else {

		/* Background settings */
		$wp_customize->add_section( 'zerif_background_settings_section', array(
			'title' => __( 'Background settings', 'zerif' ),
			'priority' => 44,
			'panel' => 'panel_background',
		));

		$wp_customize->add_setting( 'zerif_background_settings', array(
			'sanitize_callback' => 'zerif_sanitize_background_type',
		));

		$wp_customize->add_control( 'zerif_background_settings', array(
			'type' => 'radio',
			'label' => __( 'Type of background', 'zerif' ),
			'description' => __( 'Select the type of background you want.', 'zerif' ),
			'section' => 'zerif_background_settings_section',
			'choices' => array(
				'zerif-background-image' => __( 'Background image', 'zerif' ),
				'zerif-background-slider' => __( 'Background slider', 'zerif' ),
				'zerif-background-video' => __( 'Background video', 'zerif' ),
			),
			'priority' => 1,
		));

		$wp_customize->add_section( 'zerif_bgslider_section', array(
			'title' => __( 'Background slider', 'zerif' ),
			'priority' => 45,
		));

		/* slider image 1 */
		$wp_customize->add_setting( 'zerif_bgslider_1', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_1', array(
			'label' => __( 'Image 1', 'zerif' ),
			'section' => 'zerif_bgslider_section',
			'priority' => 1,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_1', array(
			'default' => 'top',
			'sanitize_callback' => 'zerif_sanitize_position',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_1', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 2,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_1', array(
			'default' => 'left',
			'sanitize_callback' => 'zerif_sanitize_horizontal',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_1', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 3,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_1', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_1', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 4,
		));

		/* slider image 2 */
		$wp_customize->add_setting( 'zerif_bgslider_2', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_2', array(
			'label' => __( 'Image 2', 'zerif' ),
			'section' => 'zerif_bgslider_section',
			'priority' => 5,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_2', array(
			'default' => 'top',
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_2', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 6,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_2', array(
			'default' => 'left',
			'sanitize_callback' => 'zerif_sanitize_horizontal',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_2', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 7,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_2', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_2', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 8,
		));

		/* slider image 3 */
		$wp_customize->add_setting( 'zerif_bgslider_3', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_bgslider_3', array(
			'label' => __( 'Image 3', 'zerif' ),
			'section' => 'zerif_bgslider_section',
			'priority' => 9,
		)));

		$wp_customize->add_setting( 'zerif_vposition_bgslider_3', array(
			'default' => 'top',
			'sanitize_callback' => 'zerif_sanitize_position',
		));

		$wp_customize->add_control( 'zerif_vposition_bgslider_3', array(
			'type' => 'select',
			'label' => 'Image Vertical align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'top' => __( 'Top', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'bottom' => __( 'Bottom', 'zerif' ),
			),
			'priority' => 10,
		));

		$wp_customize->add_setting( 'zerif_hposition_bgslider_3', array(
			'default' => 'left',
			'sanitize_callback' => 'zerif_sanitize_horizontal',
		));

		$wp_customize->add_control( 'zerif_hposition_bgslider_3', array(
			'type' => 'select',
			'label' => 'Image Horizontal align',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'left' => __( 'Left', 'zerif' ),
				'center' => __( 'Center', 'zerif' ),
				'right' => __( 'Right', 'zerif' ),
			),
			'priority' => 11,
		));

		$wp_customize->add_setting( 'zerif_bgsize_bgslider_3', array(
			'default' => 'cover',
			'sanitize_callback' => 'zerif_sanitize_background_size',
		));

		$wp_customize->add_control( 'zerif_bgsize_bgslider_3', array(
			'type' => 'select',
			'label' => 'Background size',
			'section' => 'zerif_bgslider_section',
			'choices' => array(
				'cover' => __( 'Cover', 'zerif' ),
				'width' => __( 'width 100%', 'zerif' ),
				'height' => __( 'Height 100%', 'zerif' ),
			),
			'priority' => 12,
		));

		/* Video Background */
		$wp_customize->add_section( 'zerif_background_video_section', array(
			'title' => __( 'Background Video', 'zerif' ),
			'priority' => 46,
		));

		$wp_customize->add_setting( 'zerif_background_video', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Upload_Control( $wp_customize, 'zerif_background_video', array(
			'label' => __( 'Video file', 'zerif' ),
			'description' => __( 'mp4 format file', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 1,
		)));

		/* Thumbnail */
		$wp_customize->add_setting( 'zerif_background_video_thumbnail', array(
			'sanitize_callback' => 'esc_url',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'zerif_background_video_thumbnail', array(
			'label' => __( 'Video thumbnail', 'zerif' ),
			'description' => __( 'This image will appear while the video is downloading. If this is not included, the first frame of the video will be used instead.', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 2,
		)));

		/* zerif_enable_video_sound_title */
		$wp_customize->add_setting( 'zerif_enable_video_sound_title', array(
			'sanitize_callback' => 'zerif_sanitize_pro_version',
		));
		$wp_customize->add_control( new Zerif_Video_Sound( $wp_customize, 'zerif_enable_video_sound_title', array(
			'section' => 'zerif_background_video_section',
			'priority' => 3,
		)));

		/* zerif_enable_video_sound */
		$wp_customize->add_setting( 'zerif_enable_video_sound', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_enable_video_sound', array(
			'type' => 'checkbox',
			'label' => __( 'Enable sound', 'zerif' ),
			'section' => 'zerif_background_video_section',
			'priority' => 4,
		));
	}

	/**
	 * BIG TITLE SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_3', array(
			'priority' => 33,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Big title section', 'zerif' ),
		));

		/* BIG TITLE SETTINGS */

		$wp_customize->add_section( 'zerif_bigtitle_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_3',
		));

		/* zerif_bigtitle_show */
		$wp_customize->add_setting( 'zerif_bigtitle_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_bigtitle_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide big title section?', 'zerif' ),
			'description' => __( 'If you check this box, the Big title section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_bigtitle_settings_section',
			'priority' => 1,
		));

		/* BIG TITLE CONTENT */

		$wp_customize->add_section( 'zerif_bigtitle_texts_section', array(
			'title' => __( 'Content', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_3',
		));

		/* zerif_bigtitle_title */
		$wp_customize->add_setting( 'zerif_bigtitle_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'To add a title here please go to Customizer, "Big title section"', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bigtitle_title', array(
			'label' => __( 'Big title', 'zerif' ),
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 2,
		));

		/* zerif_bigtitle_redbutton_label */
		$wp_customize->add_setting( 'zerif_bigtitle_redbutton_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'One button', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bigtitle_redbutton_label', array(
			'label' => __( 'First button label', 'zerif' ),
			'description' => __( 'This is the text that will appear on the first button', 'zerif' ),
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 3,
		));

		/* zerif_bigtitle_redbutton_url */
		$wp_customize->add_setting( 'zerif_bigtitle_redbutton_url', array(
			'sanitize_callback' => 'esc_url',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bigtitle_redbutton_url', array(
			'label' => __( 'First button link', 'zerif' ),
			'description' => __( 'The first button is linked to this URL', 'zerif' ),
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 4,
		));

		/* zerif_bigtitle_greenbutton_label */
		$wp_customize->add_setting( 'zerif_bigtitle_greenbutton_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Another button', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bigtitle_greenbutton_label', array(
			'label' => __( 'Second button label', 'zerif' ),
			'description' => __( 'This is the text that will appear on the second button', 'zerif' ),
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 5,
		));

		/* zerif_bigtitle_greenbutton_url */
		$wp_customize->add_setting( 'zerif_bigtitle_greenbutton_url', array(
			'sanitize_callback' => 'esc_url',
			'default' => '#',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bigtitle_greenbutton_url', array(
			'label' => __( 'Second button link', 'zerif' ),
			'description' => __( 'The second button is linked to this URL', 'zerif' ),
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 6,
		));

		/* Slider shortcode  */
		$zerif_bigtitle_slider_shortcode_default = '';
		if ( ! function_exists( 'nivo_slider' ) ) {
			/* translators: Nivo Slider Lite install link */
			$zerif_bigtitle_slider_shortcode_default = sprintf( __( 'You can replace the homepage slider with any plugin you like, just copy the shortcode generated and paste it here. We recommend you to use %s .', 'zerif' ), sprintf( '<a href="' . esc_url( wp_nonce_url( self_admin_url( 'update.php?action=install-plugin&plugin=nivo-slider-lite' ), 'install-plugin_nivo-slider-lite' ) ) . '" rel="nofollow">%s</a>', esc_html__( 'Nivo Slider', 'zerif' ) ) );
		}
		$wp_customize->add_setting( 'zerif_bigtitle_slider_shortcode', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));
		$wp_customize->add_control( 'zerif_bigtitle_slider_shortcode', array(
			'label' => __( 'Slider shortcode', 'zerif' ),
			'description' => $zerif_bigtitle_slider_shortcode_default,
			'section' => 'zerif_bigtitle_texts_section',
			'priority' => 7,
		));

		/* BIG TITLE COLORS */

		$wp_customize->add_section( 'zerif_bigtitle_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_3',
		));

		/* zerif_bigtitle_background */
		$wp_customize->add_setting( 'zerif_bigtitle_background', array(
			'default' => apply_filters( 'zerif_bigtitle_background_filter', 'rgba(0, 0, 0, 0.5)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_bigtitle_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 1,
		)));

		/* zerif_bigtitle_header_color */
		$wp_customize->add_setting( 'zerif_bigtitle_header_color', array(
			'default' => apply_filters( 'zerif_bigtitle_header_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_header_color', array(
			'label' => __( 'Big title color', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 2,
		)));

		/* zerif_bigtitle_1button_background_color */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_background_color', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_background_color_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_background_color', array(
			'label' => __( 'First button background color', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 3,
		)));

		/* zerif_bigtitle_1button_background_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_background_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_background_color_hover', array(
			'label' => __( 'First button background color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 4,
		)));

		/* zerif_bigtitle_1button_color */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_color', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_color', array(
			'label' => __( 'First button text color', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 5,
		)));

		/* zerif_bigtitle_1button_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_color_hover', array(
			'label' => __( 'First button text color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 6,
		)));

		/* zerif_bigtitle_2button_background_color */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_background_color', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_background_color_filter', '#20AA73' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_background_color', array(
			'label' => __( 'Second button background color', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 7,
		)));

		/* zerif_bigtitle_2button_background_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_background_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_background_color_hover_filter', '#069059' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_background_color_hover', array(
			'label' => __( 'Second button background color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 8,
		)));

		/* zerif_bigtitle_2button_color */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_color', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_color', array(
			'label' => __( 'Second button text color', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 9,
		)));

		/* zerif_bigtitle_2button_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_color_hover', array(
			'label' => __( 'Second button text color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_colors_section',
			'priority' => 10,
		)));

		/* BIG TITLE PARALLAX */
		$wp_customize->add_section( 'zerif_bigtitle_parallax_section', array(
			'title' => __( 'Parallax effect', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_3',
		));

		/* show/hide  parallax */
		$wp_customize->add_setting( 'zerif_parallax_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_parallax_show', array(
			'type' => 'checkbox',
			'label' => __( 'Use parallax effect?', 'zerif' ),
			'section' => 'zerif_bigtitle_parallax_section',
			'priority' => 1,
		));

		/* IMAGE 1*/
		$wp_customize->add_setting( 'zerif_parallax_img1', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => get_template_directory_uri() . '/images/background1.jpg',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themeslug_parallax_img1', array(
			'label' => __( 'Image 1', 'zerif' ),
			'section' => 'zerif_bigtitle_parallax_section',
			'settings' => 'zerif_parallax_img1',
			'priority' => 1,
		)));

		/* IMAGE 2 */
		$wp_customize->add_setting( 'zerif_parallax_img2', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => get_template_directory_uri() . '/images/background2.png',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themeslug_parallax_img2', array(
			'label' => __( 'Image 2', 'zerif' ),
			'section' => 'zerif_bigtitle_parallax_section',
			'settings' => 'zerif_parallax_img2',
			'priority' => 2,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_bigtitle_section', array(
			'title' => __( 'Big title section', 'zerif' ),
			'priority' => 32,
		));

		/* zerif_bigtitle_show */
		$wp_customize->add_setting( 'zerif_bigtitle_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_bigtitle_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide big title section?', 'zerif' ),
			'description' => __( 'If you check this box, the Big title section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 1,
		));

		/* zerif_bigtitle_title */
		$wp_customize->add_setting( 'zerif_bigtitle_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'To add a title here please go to Customizer, "Big title section"', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_bigtitle_title', array(
			'label' => __( 'Big title', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 2,
		));

		/* zerif_bigtitle_redbutton_label */
		$wp_customize->add_setting( 'zerif_bigtitle_redbutton_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'One button', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_bigtitle_redbutton_label', array(
			'label' => __( 'First button label', 'zerif' ),
			'description' => __( 'This is the text that will appear on the first button', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 3,
		));

		/* zerif_bigtitle_redbutton_url */
		$wp_customize->add_setting( 'zerif_bigtitle_redbutton_url', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_bigtitle_redbutton_url', array(
			'label' => __( 'First button link', 'zerif' ),
			'description' => __( 'The first button is linked to this URL', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 4,
		));

		/* zerif_bigtitle_greenbutton_label */
		$wp_customize->add_setting( 'zerif_bigtitle_greenbutton_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Another button', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_bigtitle_greenbutton_label', array(
			'label' => __( 'Second button label', 'zerif' ),
			'description' => __( 'This is the text that will appear on the second button', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 5,
		));

		/* zerif_bigtitle_greenbutton_url */
		$wp_customize->add_setting( 'zerif_bigtitle_greenbutton_url', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => '#',
		));

		$wp_customize->add_control( 'zerif_bigtitle_greenbutton_url', array(
			'label' => __( 'Second button link', 'zerif' ),
			'description' => __( 'The second button is linked to this URL', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 6,
		));

		/* zerif_bigtitle_background */
		$wp_customize->add_setting( 'zerif_bigtitle_background', array(
			'default' => 'rgba(0, 0, 0, 0.5)',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_bigtitle_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_bigtitle_section',
			'priority' => 7,
		)));

		/* zerif_bigtitle_header_color */
		$wp_customize->add_setting( 'zerif_bigtitle_header_color', array(
			'default' => apply_filters( 'zerif_bigtitle_header_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_header_color', array(
			'label' => __( 'Big title color', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 8,
		)));

		/* zerif_bigtitle_1button_background_color */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_background_color', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_background_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_background_color', array(
			'label' => __( 'First button background color', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 9,
		)));

		/* zerif_bigtitle_1button_background_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_background_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_background_color_hover', array(
			'label' => __( 'First button background color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 10,
		)));

		/* zerif_bigtitle_1button_color */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_color', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_color', array(
			'label' => __( 'First button text color', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 11,
		)));

		/* zerif_bigtitle_1button_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_1button_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_1button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_1button_color_hover', array(
			'label' => __( 'First button text color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 12,
		)));

		/* zerif_bigtitle_2button_background_color */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_background_color', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_background_color_filter', '#20AA73' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_background_color', array(
			'label' => __( 'Second button background color', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 13,
		)));

		/* zerif_bigtitle_2button_background_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_background_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_background_color_hover_filter', '#069059' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_background_color_hover', array(
			'label' => __( 'Second button background color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 14,
		)));

		/* zerif_bigtitle_2button_color */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_color', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_color', array(
			'label' => __( 'Second button text color', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 15,
		)));

		/* zerif_bigtitle_2button_color_hover */
		$wp_customize->add_setting( 'zerif_bigtitle_2button_color_hover', array(
			'default' => apply_filters( 'zerif_bigtitle_2button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_bigtitle_2button_color_hover', array(
			'label' => __( 'Second button text color - hover', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 16,
		)));

		/* show/hide  parallax */
		$wp_customize->add_setting( 'zerif_parallax_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_parallax_show', array(
			'type' => 'checkbox',
			'label' => __( 'Use parallax effect?', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'priority' => 16,
		));

		/* IMAGE 1*/
		$wp_customize->add_setting( 'zerif_parallax_img1', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => get_template_directory_uri() . '/images/background1.jpg',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themeslug_parallax_img1', array(
			'label' => __( 'Parallax image 1', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'settings' => 'zerif_parallax_img1',
			'priority' => 17,
		)));

		/* IMAGE 2 */
		$wp_customize->add_setting( 'zerif_parallax_img2', array(
			'sanitize_callback' => 'esc_url_raw',
			'default' => get_template_directory_uri() . '/images/background2.png',
		));

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themeslug_parallax_img2', array(
			'label' => __( 'Parallax image 2', 'zerif' ),
			'section' => 'zerif_bigtitle_section',
			'settings' => 'zerif_parallax_img2',
			'priority' => 18,
		)));

	}

	/**
	 * OUR FOCUS SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_4', array(
			'priority' => 33,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Our focus section', 'zerif' ),
		));

		/* OUR FOCUS SETTINGS */

		$wp_customize->add_section( 'zerif_ourfocus_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_4',
		));

		/* zerif_ourfocus_show */
		$wp_customize->add_setting( 'zerif_ourfocus_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_ourfocus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide our focus section?', 'zerif' ),
			'description' => __( 'If you check this box, the Our focus section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_ourfocus_settings_section',
			'priority' => 1,
		));

		/* OUR FOCUS CONTENT */

		$wp_customize->add_section( 'zerif_ourfocus_texts_section', array(
			'title' => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_4',
		));

		/* zerif_ourfocus_title */
		$wp_customize->add_setting( 'zerif_ourfocus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Our Focus', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ourfocus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_ourfocus_texts_section',
			'priority' => 2,
		));

		/* zerif_ourfocus_subtitle */
		$wp_customize->add_setting( 'zerif_ourfocus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Our focus section"', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ourfocus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_ourfocus_texts_section',
			'priority' => 3,
		));

		/* OUR FOCUS COLORS */

		$wp_customize->add_section( 'zerif_ourfocus_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_4',
		));

		/* zerif_ourfocus_background */
		$wp_customize->add_setting( 'zerif_ourfocus_background', array(
			'default' => apply_filters( 'zerif_ourfocus_background_filter', 'rgba(255, 255, 255, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ourfocus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 1,
		)));

		/* zerif_ourfocus_header */
		$wp_customize->add_setting( 'zerif_ourfocus_header', array(
			'default' => apply_filters( 'zerif_ourfocus_header_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_header', array(
			'label' => __( 'Main title and subtitle colors', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 2,
		)));

		/* zerif_ourfocus_box_title_color */
		$wp_customize->add_setting( 'zerif_ourfocus_box_title_color', array(
			'default' => apply_filters( 'zerif_ourfocus_box_title_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_box_title_color', array(
			'label' => __( 'Box title color', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 3,
		)));

		/* zerif_ourfocus_box_text_color */
		$wp_customize->add_setting( 'zerif_ourfocus_box_text_color', array(
			'default' => apply_filters( 'zerif_ourfocus_box_text_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_box_text_color', array(
			'label' => __( 'Box text color', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 4,
		)));

		/* zerif_ourfocus_1box */
		$wp_customize->add_setting( 'zerif_ourfocus_1box', array(
			'default' => apply_filters( 'zerif_ourfocus_1box_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_1box', array(
			'label' => __( 'First box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 5,
		)));

		/* zerif_ourfocus_2box */
		$wp_customize->add_setting( 'zerif_ourfocus_2box', array(
			'default' => apply_filters( 'zerif_ourfocus_2box_filter', '#34d293' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_2box', array(
			'label' => __( 'Second box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 6,
		)));

		/* zerif_ourfocus_3box */
		$wp_customize->add_setting( 'zerif_ourfocus_3box', array(
			'default' => apply_filters( 'zerif_ourfocus_3box_filter', '#3ab0e2' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_3box', array(
			'label' => __( 'Third box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 7,
		)));

		/* zerif_ourfocus_4box */
		$wp_customize->add_setting( 'zerif_ourfocus_4box', array(
			'default' => apply_filters( 'zerif_ourfocus_4box_filter', '#f7d861' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_4box', array(
			'label' => __( 'Fourth box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_colors_section',
			'priority' => 8,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_ourfocus_section', array(
			'title' => __( 'Our focus section', 'zerif' ),
			'priority' => 33,
		));

		/* zerif_ourfocus_show */

		$wp_customize->add_setting( 'zerif_ourfocus_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_ourfocus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide our focus section?', 'zerif' ),
			'description' => __( 'If you check this box, the Our focus section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 1,
		));

		/* zerif_ourfocus_title */

		$wp_customize->add_setting( 'zerif_ourfocus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Our Focus', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_ourfocus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 2,
		));

		/* zerif_ourfocus_subtitle */
		$wp_customize->add_setting( 'zerif_ourfocus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Our focus section"', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_ourfocus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 3,
		));

		/* zerif_ourfocus_background */
		$wp_customize->add_setting( 'zerif_ourfocus_background', array(
			'default' => apply_filters( 'zerif_ourfocus_background_filter', 'rgba(255, 255, 255, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ourfocus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ourfocus_section',
			'priority' => 4,
		)));

		/* zerif_ourfocus_header */
		$wp_customize->add_setting( 'zerif_ourfocus_header', array(
			'default' => apply_filters( 'zerif_ourfocus_header_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_header', array(
			'label' => __( 'Main title and subtitle colors', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 5,
		)));

		/* zerif_ourfocus_box_title_color */
		$wp_customize->add_setting( 'zerif_ourfocus_box_title_color', array(
			'default' => apply_filters( 'zerif_ourfocus_box_title_color_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_box_title_color', array(
			'label' => __( 'Box title color', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 7,
		)));

		/* zerif_ourfocus_box_text_color */
		$wp_customize->add_setting( 'zerif_ourfocus_box_text_color', array(
			'default' => apply_filters( 'zerif_ourfocus_box_text_color_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_box_text_color', array(
			'label' => __( 'Box text color', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 8,
		)));

		/* zerif_ourfocus_1box */
		$wp_customize->add_setting( 'zerif_ourfocus_1box', array(
			'default' => apply_filters( 'zerif_ourfocus_1box_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_1box', array(
			'label' => __( 'First box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 9,
		)));

		/* zerif_ourfocus_2box */
		$wp_customize->add_setting( 'zerif_ourfocus_2box', array(
			'default' => apply_filters( 'zerif_ourfocus_2box_filter', '#34d293' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_2box', array(
			'label' => __( 'Second box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 10,
		)));

		/* zerif_ourfocus_3box */
		$wp_customize->add_setting( 'zerif_ourfocus_3box', array(
			'default' => apply_filters( 'zerif_ourfocus_3box_filter', '#3ab0e2' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_3box', array(
			'label' => __( 'Third box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 11,
		)));

		/* zerif_ourfocus_4box */
		$wp_customize->add_setting( 'zerif_ourfocus_4box', array(
			'default' => apply_filters( 'zerif_ourfocus_4box_filter', '#f7d861' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourfocus_4box', array(
			'label' => __( 'Fourth box border color hover', 'zerif' ),
			'section' => 'zerif_ourfocus_section',
			'priority' => 12,
		)));
	}

	/**
	 * PORTFOLIO SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_5', array(
			'priority' => 34,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Portfolio section', 'zerif' ),
		));

		/* PORTFOLIO SETTINGS */

		$wp_customize->add_section( 'zerif_portofolio_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_5',
		));

		/* zerif_portofolio_show */
		$wp_customize->add_setting( 'zerif_portofolio_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide portfolio section?', 'zerif' ),
			'description' => __( 'If you check this box, the Portfolio section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_portofolio_settings_section',
			'priority' => 1,
		));

		/* zerif_portofolio_show_modal */
		$wp_customize->add_setting( 'zerif_portofolio_show_modal', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_show_modal', array(
			'type' => 'checkbox',
			'label' => __( 'Open portfolio in a lightbox?', 'zerif' ),
			'section' => 'zerif_portofolio_settings_section',
			'priority' => 2,
		));

		/* zerif_portofolio_number */
		$wp_customize->add_setting( 'zerif_portofolio_number', array(
			'sanitize_callback' => 'absint',
			'default' => '8',
		));

		$wp_customize->add_control( 'zerif_portofolio_number', array(
			'label' => __( 'Maximum number of portfolios to display on homepage', 'zerif' ),
			'section' => 'zerif_portofolio_settings_section',
			'priority' => 3,
		));

		/* PORTFOLIO CONTENT */

		$wp_customize->add_section( 'zerif_portofolio_texts_section', array(
			'title' => __( 'Content', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_5',
		));

		/* zerif_portofolio_title */
		$wp_customize->add_setting( 'zerif_portofolio_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Portfolio', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_portofolio_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_portofolio_texts_section',
			'priority' => 3,
		));

		/* zerif_portofolio_subtitle */
		$wp_customize->add_setting( 'zerif_portofolio_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Portfolio subtitle', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_portofolio_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_portofolio_texts_section',
			'priority' => 4,
		));

		/* PORTFOLIO SINGLE PAGE */

		$wp_customize->add_section( 'zerif_portofolio_single_section', array(
			'title' => __( 'Single page', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_5',
		));

		$wp_customize->add_setting( 'zerif_portofolio_single_full', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_single_full', array(
			'type' => 'checkbox',
			'label' => __( 'Full width page?', 'zerif' ),
			'description' => __( 'If you check this box, the single portfolio page will be full width, with no sidebar.', 'zerif' ),
			'section' => 'zerif_portofolio_single_section',
			'priority' => 1,
		));

		/* PORTFOLIO COLORS */

		$wp_customize->add_section( 'zerif_portofolio_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_5',
		));

		/* zerif_portofolio_background */
		$wp_customize->add_setting( 'zerif_portofolio_background', array(
			'default' => apply_filters( 'zerif_portofolio_background_filter', 'rgba(255, 255, 255, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_portofolio_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_portofolio_colors_section',
			'priority' => 1,
		)));

		/* zerif_portofolio_header */
		$wp_customize->add_setting( 'zerif_portofolio_header', array(
			'default' => apply_filters( 'zerif_portofolio_header_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_header', array(
			'label' => __( 'Main title and subtitle colors', 'zerif' ),
			'section' => 'zerif_portofolio_colors_section',
			'priority' => 2,
		)));

		/* zerif_portofolio_text */
		$wp_customize->add_setting( 'zerif_portofolio_text', array(
			'default' => apply_filters( 'zerif_portofolio_text_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_text', array(
			'label' => __( 'Portfolio box texts', 'zerif' ),
			'section' => 'zerif_portofolio_colors_section',
			'priority' => 3,
		)));

		/* zerif_portofolio_box_underline_color */
		$wp_customize->add_setting( 'zerif_portofolio_box_underline_color', array(
			'default' => apply_filters( 'zerif_portofolio_box_underline_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_box_underline_color', array(
			'label' => __( 'Portfolio box title undeline color', 'zerif' ),
			'section' => 'zerif_portofolio_colors_section',
			'priority' => 4,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_portofolio_section', array(
			'title' => __( 'Portfolio section', 'zerif' ),
			'priority' => 34,
		));

		/* zerif_portofolio_show */
		$wp_customize->add_setting( 'zerif_portofolio_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide portfolio section?', 'zerif' ),
			'description' => __( 'If you check this box, the Portfolio section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 1,
		));

		/* zerif_portofolio_show_modal */
		$wp_customize->add_setting( 'zerif_portofolio_show_modal', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_show_modal', array(
			'type' => 'checkbox',
			'label' => __( 'Open portfolio in a lightbox?', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 2,
		));

		/* zerif_portofolio_number */
		$wp_customize->add_setting( 'zerif_portofolio_number', array(
			'sanitize_callback' => 'absint',
			'default' => '8',
		));

		$wp_customize->add_control( 'zerif_portofolio_number', array(
			'label' => __( 'Maximum number of portfolios to display on homepage', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 3,
		));

		/* zerif_portofolio_title */
		$wp_customize->add_setting( 'zerif_portofolio_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Portfolio', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_portofolio_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 4,
		));

		/* zerif_portofolio_subtitle */
		$wp_customize->add_setting( 'zerif_portofolio_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Portfolio subtitle', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_portofolio_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 5,
		));

		/* zerif_portofolio_single_full */
		$wp_customize->add_setting( 'zerif_portofolio_single_full', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_portofolio_single_full', array(
			'type' => 'checkbox',
			'label' => __( 'Full width page?', 'zerif' ),
			'description' => __( 'If you check this box, the single portfolio page will be full width, with no sidebar.', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 6,
		));

		/* zerif_portofolio_background */
		$wp_customize->add_setting( 'zerif_portofolio_background', array(
			'default' => apply_filters( 'zerif_portofolio_background_filter', 'rgba(255, 255, 255, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_portofolio_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_portofolio_section',
			'priority' => 7,
		)));

		/* zerif_portofolio_header */
		$wp_customize->add_setting( 'zerif_portofolio_header', array(
			'default' => apply_filters( 'zerif_portofolio_header_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_header', array(
			'label' => __( 'Main title and subtitle colors', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 8,
		)));

		/* zerif_portofolio_text */
		$wp_customize->add_setting( 'zerif_portofolio_text', array(
			'default' => apply_filters( 'zerif_portofolio_text_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_text', array(
			'label' => __( 'Portfolio box texts', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 9,
		)));

		/* zerif_portofolio_box_underline_color */
		$wp_customize->add_setting( 'zerif_portofolio_box_underline_color', array(
			'default' => apply_filters( 'zerif_portofolio_box_underline_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_portofolio_box_underline_color', array(
			'label' => __( 'Portfolio box title undeline color', 'zerif' ),
			'section' => 'zerif_portofolio_section',
			'priority' => 10,
		)));
	}

	/**
	 * ABOUT US SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_6', array(
			'priority' => 35,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'About us section', 'zerif' ),
		));

		/* ABOUT US SETTINGS */
		$wp_customize->add_section( 'zerif_aboutus_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_show */
		$wp_customize->add_setting( 'zerif_aboutus_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_aboutus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide about us section?', 'zerif' ),
			'description' => __( 'If you check this box, the About us section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_aboutus_settings_section',
			'priority' => 1,
		));

		/* ABOUT US CONTENT */

		$wp_customize->add_section( 'zerif_aboutus_texts_section', array(
			'title' => __( 'Main content', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_title */
		$wp_customize->add_setting( 'zerif_aboutus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'About US', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_aboutus_texts_section',
			'priority' => 1,
		));

		/* zerif_aboutus_subtitle */
		$wp_customize->add_setting( 'zerif_aboutus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "About us section"', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_aboutus_texts_section',
			'priority' => 2,
		));

		/* zerif_aboutus_biglefttitle */
		$wp_customize->add_setting( 'zerif_aboutus_biglefttitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Title', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_biglefttitle', array(
			'label' => __( 'Left side content', 'zerif' ),
			'section' => 'zerif_aboutus_texts_section',
			'priority' => 3,
		));

		/* zerif_aboutus_text */
		$wp_customize->add_setting( 'zerif_aboutus_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'You can add here a large piece of text. For that, please go in the Admin Area, Customizer, "About us section"', 'zerif' ),
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_aboutus_text', array(
			'label' => __( 'Middle content', 'zerif' ),
			'section' => 'zerif_aboutus_texts_section',
			'priority' => 4,
		)));

		/* ABOUT US FEATURE 1 */

		$wp_customize->add_section( 'zerif_aboutus_feature1_section', array(
			'title' => __( 'Feature no#1', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_feature1_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature1_title', array(
			'label' => __( 'Title', 'zerif' ),
			'section' => 'zerif_aboutus_feature1_section',
			'priority' => 1,
		));

		/* zerif_aboutus_feature1_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature1_text', array(
			'label' => __( 'Text', 'zerif' ),
			'section' => 'zerif_aboutus_feature1_section',
			'priority' => 2,
		));

		/* zerif_aboutus_feature1_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '50',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature1_nr', array(
			'type' => 'number',
			'label' => __( 'Percentage', 'zerif' ),
			'section' => 'zerif_aboutus_feature1_section',
			'priority' => 3,
		)));

		/* zerif_aboutus_feature1_color */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_color', array(
			'default' => apply_filters( 'zerif_aboutus_feature1_color_filter', '#E96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_feature1_color', array(
			'label' => __( 'Knob Color', 'zerif' ),
			'section' => 'zerif_aboutus_feature1_section',
			'priority' => 4,
		)));

		/* ABOUT US FEATURE 2 */

		$wp_customize->add_section( 'zerif_aboutus_feature2_section', array(
			'title' => __( 'Feature no#2', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_feature2_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature2_title', array(
			'label' => __( 'Title', 'zerif' ),
			'section' => 'zerif_aboutus_feature2_section',
			'priority' => 1,
		));

		/* zerif_aboutus_feature2_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature2_text', array(
			'label' => __( 'Text', 'zerif' ),
			'section' => 'zerif_aboutus_feature2_section',
			'priority' => 2,
		));

		/* zerif_aboutus_feature2_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '70',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature2_nr', array(
			'type' => 'number',
			'label' => __( 'Percentage', 'zerif' ),
			'section' => 'zerif_aboutus_feature2_section',
			'priority' => 3,
		)));

		/* zerif_aboutus_feature2_color */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_color', array(
			'default' => apply_filters( 'zerif_aboutus_feature2_color_filter', '#34D293' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_feature2_color', array(
			'label' => __( 'Knob Color', 'zerif' ),
			'section' => 'zerif_aboutus_feature2_section',
			'priority' => 4,
		)));

		/* ABOUT US FEATURE 3 */

		$wp_customize->add_section( 'zerif_aboutus_feature3_section', array(
			'title' => __( 'Feature no#3', 'zerif' ),
			'priority' => 5,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_feature3_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature3_title', array(
			'label' => __( 'Title', 'zerif' ),
			'section' => 'zerif_aboutus_feature3_section',
			'priority' => 1,
		));

		/* zerif_aboutus_feature3_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature3_text', array(
			'label' => __( 'Text', 'zerif' ),
			'section' => 'zerif_aboutus_feature3_section',
			'priority' => 2,
		));

		/* zerif_aboutus_feature3_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '100',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature3_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no3 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_feature3_section',
			'priority' => 3,
		)));

		/* zerif_aboutus_feature3_color */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_color', array(
			'default' => apply_filters( 'zerif_aboutus_feature3_color_filter', '#3AB0E2' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_feature3_color', array(
			'label' => __( 'Knob Color', 'zerif' ),
			'section' => 'zerif_aboutus_feature3_section',
			'priority' => 4,
		)));

		/* ABOUT US FEATURE 4 */

		$wp_customize->add_section( 'zerif_aboutus_feature4_section', array(
			'title' => __( 'Feature no#4', 'zerif' ),
			'priority' => 6,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_feature4_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature4_title', array(
			'label' => __( 'Title', 'zerif' ),
			'section' => 'zerif_aboutus_feature4_section',
			'priority' => 1,
		));

		/* zerif_aboutus_feature4_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature4_text', array(
			'label' => __( 'Text', 'zerif' ),
			'section' => 'zerif_aboutus_feature4_section',
			'priority' => 2,
		));

		/* zerif_aboutus_feature4_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '10',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature4_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no4 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_feature4_section',
			'priority' => 3,
		)));

		/* zerif_aboutus_feature4_color */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_color', array(
			'default' => apply_filters( 'zerif_aboutus_feature4_color_filter', '#E7AC44' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_feature4_color', array(
			'label' => __( 'Knob Color', 'zerif' ),
			'section' => 'zerif_aboutus_feature4_section',
			'priority' => 4,
		)));

		/* ABOUT US COLORS */

		$wp_customize->add_section( 'zerif_aboutus_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 7,
			'panel' => 'panel_6',
		));

		/* zerif_aboutus_background */
		$wp_customize->add_setting( 'zerif_aboutus_background', array(
			'default' => apply_filters( 'zerif_aboutus_background_filter', 'rgba(39, 39, 39, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_aboutus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_aboutus_colors_section',
			'priority' => 1,
		)));

		/* zerif_aboutus_title_color */
		$wp_customize->add_setting( 'zerif_aboutus_title_color', array(
			'default' => apply_filters( 'zerif_aboutus_title_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_title_color', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_aboutus_colors_section',
			'priority' => 2,
		)));

		/* zerif_aboutus_number_color */
		$wp_customize->add_setting( 'zerif_aboutus_number_color', array(
			'default' => apply_filters( 'zerif_aboutus_number_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_number_color', array(
			'label' => __( 'Numbers color', 'zerif' ),
			'section' => 'zerif_aboutus_colors_section',
			'priority' => 3,
		)));

		/* zerif_aboutus_clients_color */
		$wp_customize->add_setting( 'zerif_aboutus_clients_color', array(
			'default' => apply_filters( 'zerif_aboutus_clients_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_clients_color', array(
			'label' => __( 'Clients title color', 'zerif' ),
			'section' => 'zerif_aboutus_colors_section',
			'priority' => 4,
		)));

		/* ABOUT US CLIENTS TITLE */

		$wp_customize->add_section( 'zerif_aboutus_clients_title_section', array(
			'title' => __( 'Clients area title', 'zerif' ),
			'priority' => 9,
			'panel' => 'panel_6',
		));

		$wp_customize->add_setting( 'zerif_aboutus_clients_title_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'OUR HAPPY CLIENTS', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_aboutus_clients_title_text', array(
			'label' => __( 'Title', 'zerif' ),
			'description' => __( 'This title appears only if you have widgets in the About us sidebar.', 'zerif' ),
			'section' => 'zerif_aboutus_clients_title_section',
			'priority' => 1,
		));

	} else {

		$wp_customize->add_section( 'zerif_aboutus_section', array(
			'title' => __( 'About us section', 'zerif' ),
			'priority' => 35,
		));

		/* zerif_aboutus_show */
		$wp_customize->add_setting( 'zerif_aboutus_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_aboutus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide about us section?', 'zerif' ),
			'description' => __( 'If you check this box, the About us section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 1,
		));

		/* zerif_aboutus_title */
		$wp_customize->add_setting( 'zerif_aboutus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'About US', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 2,
		));

		/* zerif_aboutus_subtitle */
		$wp_customize->add_setting( 'zerif_aboutus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "About us section"', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 3,
		));

		/* zerif_aboutus_biglefttitle */
		$wp_customize->add_setting( 'zerif_aboutus_biglefttitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Title', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_biglefttitle', array(
			'label' => __( 'Left side content', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 4,
		));

		/* zerif_aboutus_text */
		$wp_customize->add_setting( 'zerif_aboutus_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'You can add here a large piece of text. For that, please go in the Admin Area, Customizer, "About us section"', 'zerif' ),
		));

		$wp_customize->add_control( new Zerif_Customize_Textarea_Control( $wp_customize, 'zerif_aboutus_text', array(
			'label' => __( 'Middle content', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 5,
		)));

		/* zerif_aboutus_feature1_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_feature1_title', array(
			'label' => __( 'Feature no1 title', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 6,
		));

		/* zerif_aboutus_feature1_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature1_text', array(
			'label' => __( 'Feature no1 text', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 7,
		));

		/* zerif_aboutus_feature1_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature1_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '50',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature1_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no1 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 8,
		)));

		/* zerif_aboutus_feature2_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_feature2_title', array(
			'label' => __( 'Feature no2 title', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 9,
		));

		/* zerif_aboutus_feature2_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature2_text', array(
			'label' => __( 'Feature no2 text', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 10,
		));

		/* zerif_aboutus_feature2_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature2_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '70',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature2_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no2 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 11,
		)));

		/* zerif_aboutus_feature3_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_feature3_title', array(
			'label' => __( 'Feature no3 title', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 12,
		));

		/* zerif_aboutus_feature3_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature3_text', array(
			'label' => __( 'Feature no3 text', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 13,
		));

		/* zerif_aboutus_feature3_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature3_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '100',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature3_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no3 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 14,
		)));

		/* zerif_aboutus_feature4_title */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Feature', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_feature4_title', array(
			'label' => __( 'Feature no4 title', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 15,
		));

		/* zerif_aboutus_feature4_text */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_aboutus_feature4_text', array(
			'label' => __( 'Feature no4 text', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 16,
		));

		/* zerif_aboutus_feature4_nr */
		$wp_customize->add_setting( 'zerif_aboutus_feature4_nr', array(
			'sanitize_callback' => 'absint',
			'default' => '10',
		));

		$wp_customize->add_control( new Zerif_Customizer_Number_Control( $wp_customize, 'zerif_aboutus_feature4_nr', array(
			'type' => 'number',
			'label' => __( 'Feature no4 percentage', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 17,
		)));

		/* zerif_aboutus_background */
		$wp_customize->add_setting( 'zerif_aboutus_background', array(
			'default' => apply_filters( 'zerif_aboutus_background_filter', 'rgba(39, 39, 39, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_aboutus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_aboutus_section',
			'priority' => 18,
		)));

		/* zerif_aboutus_title_color */
		$wp_customize->add_setting( 'zerif_aboutus_title_color', array(
			'default' => apply_filters( 'zerif_aboutus_title_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_title_color', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 19,
		)));

		$wp_customize->add_setting( 'zerif_aboutus_clients_title_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'OUR HAPPY CLIENTS', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_aboutus_clients_title_text', array(
			'label' => __( 'Clients widgets area title', 'zerif' ),
			'description' => __( 'This title appears only if you have widgets in the About us sidebar.', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 20,
		));

		/* zerif_aboutus_number_color */
		$wp_customize->add_setting( 'zerif_aboutus_number_color', array(
			'default' => apply_filters( 'zerif_aboutus_number_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_number_color', array(
			'label' => __( 'Numbers color', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 21,
		)));

		/* zerif_aboutus_clients_color */
		$wp_customize->add_setting( 'zerif_aboutus_clients_color', array(
			'default' => apply_filters( 'zerif_aboutus_clients_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_aboutus_clients_color', array(
			'label' => __( 'Clients title color', 'zerif' ),
			'section' => 'zerif_aboutus_section',
			'priority' => 22,
		)));

	}

	/**
	 * OUR TEAM SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_7', array(
			'priority' => 36,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Our team section', 'zerif' ),
		));

		/* OUR TEAM SETTINGS */

		$wp_customize->add_section( 'zerif_ourteam_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_7',
		));

		/* zerif_ourteam_show */
		$wp_customize->add_setting( 'zerif_ourteam_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_ourteam_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide our team section?', 'zerif' ),
			'description' => __( 'If you check this box, the Our team section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_ourteam_settings_section',
			'priority' => 1,
		));

		/* OUR TEAM HEADER */

		$wp_customize->add_section( 'zerif_ourteam_texts_section', array(
			'title' => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_7',
		));

		/* zerif_ourteam_title */
		$wp_customize->add_setting( 'zerif_ourteam_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Our Team', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ourteam_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_ourteam_texts_section',
			'priority' => 2,
		));

		/* zerif_ourteam_subtitle */
		$wp_customize->add_setting( 'zerif_ourteam_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Our team section"', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ourteam_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_ourteam_texts_section',
			'priority' => 3,
		));

		/* OUR TEAM COLORS */

		/* zerif_ourteam_colors_section */
		$wp_customize->add_section( 'zerif_ourteam_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_7',
		));

		/* zerif_ourteam_background */
		$wp_customize->add_setting( 'zerif_ourteam_background', array(
			'default' => apply_filters( 'zerif_ourteam_background_filter', 'rgba(255, 255, 255, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ourteam_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 1,
		)));

		/* zerif_ourteam_header */
		$wp_customize->add_setting( 'zerif_ourteam_header', array(
			'default' => apply_filters( 'zerif_ourteam_header_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_header', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 2,
		)));

		/* zerif_ourteam_text */
		$wp_customize->add_setting( 'zerif_ourteam_text', array(
			'default' => apply_filters( 'zerif_ourteam_text_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_text', array(
			'label' => __( 'Team member hover description color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 3,
		)));

		/* zerif_ourteam_hover_background */
		$wp_customize->add_setting( 'zerif_ourteam_hover_background', array(
			'default' => apply_filters( 'zerif_ourteam_hover_background_filter', '#333' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_hover_background', array(
			'label' => __( 'Team member hover description background color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 4,
		)));

		/* zerif_ourteam_socials */
		$wp_customize->add_setting( 'zerif_ourteam_socials', array(
			'default' => apply_filters( 'zerif_ourteam_socials_filter', '#808080' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_socials', array(
			'label' => __( 'Social icons colors', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 5,
		)));

		/* zerif_ourteam_socials_hover */
		$wp_customize->add_setting( 'zerif_ourteam_socials_hover', array(
			'default' => apply_filters( 'zerif_ourteam_socials_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_socials_hover', array(
			'label' => __( 'Social icons colors - hover', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 6,
		)));

		/* zerif_ourteam_1box */
		$wp_customize->add_setting( 'zerif_ourteam_1box', array(
			'default' => apply_filters( 'zerif_ourteam_1box_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_1box', array(
			'label' => __( 'First box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 7,
		)));

		/* zerif_ourteam_2box */
		$wp_customize->add_setting( 'zerif_ourteam_2box', array(
			'default' => '#34d293',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_2box', array(
			'label' => __( 'Second box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 8,
		)));

		/* zerif_ourteam_3box */
		$wp_customize->add_setting( 'zerif_ourteam_3box', array(
			'default' => '#3ab0e2',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_3box', array(
			'label' => __( 'Third box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 9,
		)));

		/* zerif_ourteam_4box */
		$wp_customize->add_setting( 'zerif_ourteam_4box', array(
			'default' => '#f7d861',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_4box', array(
			'label' => __( 'Fourth box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_colors_section',
			'priority' => 10,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_ourteam_section', array(
			'title' => __( 'Our team section', 'zerif' ),
			'priority' => 36,
		));

		/* zerif_ourteam_show */
		$wp_customize->add_setting( 'zerif_ourteam_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_ourteam_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide our team section?', 'zerif' ),
			'description' => __( 'If you check this box, the Our team section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 1,
		));

		/* zerif_ourteam_title */
		$wp_customize->add_setting( 'zerif_ourteam_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Our Team', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_ourteam_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 2,
		));

		/* zerif_ourteam_subtitle */
		$wp_customize->add_setting( 'zerif_ourteam_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Our team section"', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_ourteam_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 3,
		));

		/* zerif_ourteam_background */
		$wp_customize->add_setting( 'zerif_ourteam_background', array(
			'default' => apply_filters( 'zerif_ourteam_background_filter', 'rgba(255, 255, 255, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ourteam_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ourteam_section',
			'priority' => 4,
		)));

		/* zerif_ourteam_header */
		$wp_customize->add_setting( 'zerif_ourteam_header', array(
			'default' => apply_filters( 'zerif_ourteam_header_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_header', array(
			'label' => __( 'Titles color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 5,
		)));

		/* zerif_ourteam_text */
		$wp_customize->add_setting( 'zerif_ourteam_text', array(
			'default' => apply_filters( 'zerif_ourteam_text_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_text', array(
			'label' => __( 'Team member hover description color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 6,
		)));

		/* zerif_ourteam_hover_background */
		$wp_customize->add_setting( 'zerif_ourteam_hover_background', array(
			'default' => apply_filters( 'zerif_ourteam_hover_background_filter', '#333' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_hover_background', array(
			'label' => __( 'Team member hover description background color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 7,
		)));

		/* zerif_ourteam_socials */
		$wp_customize->add_setting( 'zerif_ourteam_socials', array(
			'default' => apply_filters( 'zerif_ourteam_socials_filter', '#808080' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_socials', array(
			'label' => __( 'Social icons colors', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 8,
		)));

		/* zerif_ourteam_socials_hover */
		$wp_customize->add_setting( 'zerif_ourteam_socials_hover', array(
			'default' => apply_filters( 'zerif_ourteam_socials_hover_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_socials_hover', array(
			'label' => __( 'Social icons colors - hover', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 9,
		)));

		/* zerif_ourteam_1box */
		$wp_customize->add_setting( 'zerif_ourteam_1box', array(
			'default' => apply_filters( 'zerif_ourteam_1box_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_1box', array(
			'label' => __( 'First box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 10,
		)));

		/* zerif_ourteam_2box */
		$wp_customize->add_setting( 'zerif_ourteam_2box', array(
			'default' => apply_filters( 'zerif_ourteam_2box_filter', '#34d293' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_2box', array(
			'label' => __( 'Second box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 11,
		)));

		/* zerif_ourteam_3box */
		$wp_customize->add_setting( 'zerif_ourteam_3box', array(
			'default' => apply_filters( 'zerif_ourteam_3box_filter', '#3ab0e2' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_3box', array(
			'label' => __( 'Third box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 12,
		)));

		/* zerif_ourteam_4box */
		$wp_customize->add_setting( 'zerif_ourteam_4box', array(
			'default' => apply_filters( 'zerif_ourteam_4box_filter', '#f7d861' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ourteam_4box', array(
			'label' => __( 'Fourth box title underline color', 'zerif' ),
			'section' => 'zerif_ourteam_section',
			'priority' => 13,
		)));
	}

	/**
	 * TESTIMONIALS SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_8', array(
			'priority' => 37,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Testimonials section', 'zerif' ),
		));

		/* TESTIMONIALS SETTINGS */

		$wp_customize->add_section( 'zerif_testimonials_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_8',
		));

		/* zerif_testimonials_show */
		$wp_customize->add_setting( 'zerif_testimonials_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_testimonials_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide testimonials section?', 'zerif' ),
			'description' => __( 'If you check this box, the Testimonials section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_testimonials_settings_section',
			'priority' => 1,
		));

		$wp_customize->add_setting( 'zerif_testimonials_pinterest_style', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_testimonials_pinterest_style', array(
			'type' => 'checkbox',
			'label' => __( 'Use pinterest layout?', 'zerif' ),
			'description' => __( 'If you check this box, the Testimonials section will use pinterest-style layout.', 'zerif' ),
			'section' => 'zerif_testimonials_settings_section',
			'priority' => 2,
		));

		/* TESTIMONIALS HEADER */

		$wp_customize->add_section( 'zerif_testimonials_texts_section', array(
			'title' => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_8',
		));

		/* zerif_testimonials_title */
		$wp_customize->add_setting( 'zerif_testimonials_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Testimonials', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_testimonials_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_testimonials_texts_section',
			'priority' => 2,
		));

		/* zerif_testimonials_subtitle */
		$wp_customize->add_setting( 'zerif_testimonials_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_testimonials_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_testimonials_texts_section',
			'priority' => 3,
		));

		/* TESTIMONIALS COLORS */

		$wp_customize->add_section( 'zerif_testimonials_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_8',
		));

		/* zerif_testimonials_background */
		$wp_customize->add_setting( 'zerif_testimonials_background', array(
			'default' => apply_filters( 'zerif_testimonials_background_filter', 'rgba(219, 191, 86, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_testimonials_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 1,
		)));

		/* zerif_testimonials_header */
		$wp_customize->add_setting( 'zerif_testimonials_header', array(
			'default' => apply_filters( 'zerif_testimonials_header_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_header', array(
			'label' => __( 'Title and subtitle colors', 'zerif' ),
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 2,
		)));

		/* zerif_testimonials_text */
		$wp_customize->add_setting( 'zerif_testimonials_text', array(
			'default' => apply_filters( 'zerif_testimonials_text_filter', '#909090' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_text', array(
			'label' => __( 'Testimonial text color', 'zerif' ),
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 3,
		)));

		/* zerif_testimonials_author */
		$wp_customize->add_setting( 'zerif_testimonials_author', array(
			'default' => apply_filters( 'zerif_testimonials_author_filter', '#909090' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_author', array(
			'label' => __( 'Testimonial author name color', 'zerif' ),
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 4,
		)));

		/* zerif_testimonials_quote */
		$wp_customize->add_setting( 'zerif_testimonials_quote', array(
			'default' => apply_filters( 'zerif_testimonials_quote_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_quote', array(
			'label' => __( 'Testimonial quote color', 'zerif' ),
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 5,
		)));

		/* zerif_testimonials_box_color */
		$wp_customize->add_setting( 'zerif_testimonials_box_color', array(
			'default' => apply_filters( 'zerif_testimonials_box_color_filter', '#FFFFFF' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_box_color', array(
			'label' => __( 'Testimonial box background color', 'zerif' ),
			'section' => 'zerif_testimonials_colors_section',
			'priority' => 6,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_testimonials_section', array(
			'title' => __( 'Testimonials section', 'zerif' ),
			'priority' => 37,
		));

		/* zerif_testimonials_show */
		$wp_customize->add_setting( 'zerif_testimonials_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_testimonials_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide testimonials section?', 'zerif' ),
			'description' => __( 'If you check this box, the Testimonials section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 1,
		));

		/* zerif_testimonials_title */
		$wp_customize->add_setting( 'zerif_testimonials_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Testimonials', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_testimonials_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 2,
		));

		/* zerif_testimonials_subtitle */
		$wp_customize->add_setting( 'zerif_testimonials_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_testimonials_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 3,
		));

		/* zerif_testimonials_background */
		$wp_customize->add_setting( 'zerif_testimonials_background', array(
			'default' => apply_filters( 'zerif_testimonials_background_filter', 'rgba(219, 191, 86, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_testimonials_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_testimonials_section',
			'priority' => 4,
		)));

		/* zerif_testimonials_header */
		$wp_customize->add_setting( 'zerif_testimonials_header', array(
			'default' => apply_filters( 'zerif_testimonials_header_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_header', array(
			'label' => __( 'Title and subtitle colors', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 5,
		)));

		/* zerif_testimonials_text */
		$wp_customize->add_setting( 'zerif_testimonials_text', array(
			'default' => apply_filters( 'zerif_testimonials_text_filter', '#909090' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_text', array(
			'label' => __( 'Testimonial text color', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 6,
		)));

		/* zerif_testimonials_author */
		$wp_customize->add_setting( 'zerif_testimonials_author', array(
			'default' => apply_filters( 'zerif_testimonials_author_filter', '#909090' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_author', array(
			'label' => __( 'Testimonial author name color', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 7,
		)));

		/* zerif_testimonials_quote */
		$wp_customize->add_setting( 'zerif_testimonials_quote', array(
			'default' => apply_filters( 'zerif_testimonials_quote_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_quote', array(
			'label' => __( 'Testimonial quote color', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 8,
		)));

		/* zerif_testimonials_box_color */
		$wp_customize->add_setting( 'zerif_testimonials_box_color', array(
			'default' => apply_filters( 'zerif_testimonials_box_color_filter', '#FFFFFF' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_testimonials_box_color', array(
			'label' => __( 'Testimonial box background color', 'zerif' ),
			'section' => 'zerif_testimonials_section',
			'priority' => 9,
		)));

	}

	/**
	 * RIBBONS
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_9', array(
			'priority' => 38,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Ribbon sections', 'zerif' ),
		));

		$wp_customize->add_section( 'zerif_bottombribbon_section', array(
			'title' => __( 'BottomButton Ribbon', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_9',
		));

		/* RIBBON SECTION WITH BOTTOM BUTTON */

		/* zerif_bottomribbon_text */
		$wp_customize->add_setting( 'zerif_bottomribbon_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_text', array(
			'label' => __( 'Main text', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 1,
		));

		/* zerif_bottomribbon_buttonlabel */
		$wp_customize->add_setting( 'zerif_bottomribbon_buttonlabel', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_buttonlabel', array(
			'label' => __( 'Button label', 'zerif' ),
			'description' => __( 'The button link must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 2,
		));

		/* zerif_bottomribbon_buttonlink */
		$wp_customize->add_setting( 'zerif_bottomribbon_buttonlink', array(
			'sanitize_callback' => 'esc_url',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_buttonlink', array(
			'label' => __( 'Button link', 'zerif' ),
			'description' => __( 'The button label must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 3,
		));

		/* zerif_ribbon_background */
		$wp_customize->add_setting( 'zerif_ribbon_background', array(
			'default' => apply_filters( 'zerif_ribbon_background_filter', 'rgba(52, 210, 147, 0.8)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ribbon_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_bottombribbon_section',
			'priority' => 4,
		)));

		/* zerif_ribbon_text_color */
		$wp_customize->add_setting( 'zerif_ribbon_text_color', array(
			'default' => apply_filters( 'zerif_ribbon_text_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_text_color', array(
			'label' => __( 'Text color', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 5,
		)));

		/* zerif_ribbon_button_background */
		$wp_customize->add_setting( 'zerif_ribbon_button_background', array(
			'default' => apply_filters( 'zerif_ribbon_button_background_filter', '#20AA73' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_background', array(
			'label' => __( 'Button background color', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 6,
		)));

		/* zerif_ribbon_button_background_hover */
		$wp_customize->add_setting( 'zerif_ribbon_button_background_hover', array(
			'default' => apply_filters( 'zerif_ribbon_button_background_hover_filter', '#14a168' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_background_hover', array(
			'label' => __( 'Button background color hover', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 7,
		)));

		/* zerif_ribbon_button_button_color */
		$wp_customize->add_setting( 'zerif_ribbon_button_button_color', array(
			'default' => apply_filters( 'zerif_ribbon_button_button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 8,
		)));

		/* zerif_ribbon_button_button_color_hover */
		$wp_customize->add_setting( 'zerif_ribbon_button_button_color_hover', array(
			'default' => apply_filters( 'zerif_ribbon_button_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_button_color_hover', array(
			'label' => __( 'Button text color hover', 'zerif' ),
			'section' => 'zerif_bottombribbon_section',
			'priority' => 9,
		)));

		/* RIBBON SECTION WITH BUTTON IN THE RIGHT SIDE */

		$wp_customize->add_section( 'zerif_rightbribbon_section', array(
			'title' => __( 'RightButton Ribbon', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_9',
		));

		/* zerif_ribbonright_text */
		$wp_customize->add_setting( 'zerif_ribbonright_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ribbonright_text', array(
			'label' => __( 'Main text', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 1,
		));

		/* zerif_ribbonright_buttonlabel */
		$wp_customize->add_setting( 'zerif_ribbonright_buttonlabel', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ribbonright_buttonlabel', array(
			'label' => __( 'Button label', 'zerif' ),
			'description' => __( 'The button link must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 2,
		));

		/* zerif_ribbonright_buttonlink */
		$wp_customize->add_setting( 'zerif_ribbonright_buttonlink', array(
			'sanitize_callback' => 'esc_url_raw',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_ribbonright_buttonlink', array(
			'label' => __( 'Button link', 'zerif' ),
			'description' => __( 'The button label must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 3,
		));

		/* zerif_ribbonright_background */
		$wp_customize->add_setting( 'zerif_ribbonright_background', array(
			'default' => apply_filters( 'zerif_ribbonright_background_filter', 'rgba(233, 102, 86, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ribbonright_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_rightbribbon_section',
			'priority' => 4,
		)));

		/* zerif_ribbonright_text_color */
		$wp_customize->add_setting( 'zerif_ribbonright_text_color', array(
			'default' => apply_filters( 'zerif_ribbonright_text_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_text_color', array(
			'label' => __( 'Text color', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 5,
		)));

		/* zerif_ribbonright_button_background */
		$wp_customize->add_setting( 'zerif_ribbonright_button_background', array(
			'default' => apply_filters( 'zerif_ribbonright_button_background_filter', '#db5a4a' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_background', array(
			'label' => __( 'Button background color', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 6,
		)));

		/* zerif_ribbonright_button_background_hover */
		$wp_customize->add_setting( 'zerif_ribbonright_button_background_hover', array(
			'default' => apply_filters( 'zerif_ribbonright_button_background_hover_filter', '#bf3928' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_background_hover', array(
			'label' => __( 'Button background color hover', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 7,
		)));

		/* zerif_ribbonright_button_button_color */
		$wp_customize->add_setting( 'zerif_ribbonright_button_button_color', array(
			'default' => apply_filters( 'zerif_ribbonright_button_button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 8,
		)));

		/* zerif_ribbonright_button_button_color_hover */
		$wp_customize->add_setting( 'zerif_ribbonright_button_button_color_hover', array(
			'default' => apply_filters( 'zerif_ribbonright_button_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_button_color_hover', array(
			'label' => __( 'Button text color hover', 'zerif' ),
			'section' => 'zerif_rightbribbon_section',
			'priority' => 9,
		)));

		require_once( 'class/zerif-general-control.php' );

		$wp_customize->add_section( 'zerif_shortcodes_section', array(
			'title' => esc_html__( 'Shortcodes section', 'zerif' ),
			'priority' => 38,
		));

		$wp_customize->add_setting( 'zerif_shortcodes_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_shortcodes_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide shortcodes section?', 'zerif' ),
			'description' => __( 'If you check this box, the Shortcodes section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_shortcodes_section',
			'priority' => 1,
		));

		$wp_customize->add_setting( 'zerif_shortcodes_settings', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_repeater',
		));
		$wp_customize->add_control( new Zerif_General_Repeater( $wp_customize, 'zerif_shortcodes_settings', array(
			'label' => esc_html__( 'Edit the shortcode options', 'zerif' ),
			'section' => 'zerif_shortcodes_section',
			'priority' => 2,
			'zerif_title_control' => true,
			'zerif_subtitle_control' => true,
			'zerif_shortcode_control' => true,
			'zerif_color_control' => true,
			'zerif_opacity_control' => true,
			'zerif_text_color_control' => true,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_ribbon_section', array(
			'title' => __( 'Ribbon sections', 'zerif' ),
			'priority' => 38,
		));

		/* RIBBON SECTION WITH BOTTOM BUTTON */

		/* zerif_bottomribbon_text */
		$wp_customize->add_setting( 'zerif_bottomribbon_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_text', array(
			'label' => __( 'BottomButton Ribbon - Main text', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 1,
		));

		/* zerif_bottomribbon_buttonlabel */
		$wp_customize->add_setting( 'zerif_bottomribbon_buttonlabel', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_buttonlabel', array(
			'label' => __( 'BottomButton Ribbon - Button label', 'zerif' ),
			'description' => __( 'The button link must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 2,
		));

		/* zerif_bottomribbon_buttonlink */
		$wp_customize->add_setting( 'zerif_bottomribbon_buttonlink', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_bottomribbon_buttonlink', array(
			'label' => __( 'BottomButton Ribbon - Button link', 'zerif' ),
			'description' => __( 'The button label must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 3,
		));

		/* zerif_ribbon_background */
		$wp_customize->add_setting( 'zerif_ribbon_background', array(
			'default' => apply_filters( 'zerif_ribbon_background_filter', 'rgba(52, 210, 147, 0.8)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ribbon_background', array(
			'label' => __( 'BottomButton Ribbon - background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ribbon_section',
			'priority' => 4,
		)));

		/* zerif_ribbon_text_color */
		$wp_customize->add_setting( 'zerif_ribbon_text_color', array(
			'default' => apply_filters( 'zerif_ribbon_text_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_text_color', array(
			'label' => __( 'BottomButton Ribbon - text color', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 5,
		)));

		/* zerif_ribbon_button_background */
		$wp_customize->add_setting( 'zerif_ribbon_button_background', array(
			'default' => apply_filters( 'zerif_ribbon_button_background_filter', '#20AA73' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_background', array(
			'label' => __( 'BottomButton Ribbon - button background color', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 6,
		)));

		/* zerif_ribbon_button_background_hover */
		$wp_customize->add_setting( 'zerif_ribbon_button_background_hover', array(
			'default' => apply_filters( 'zerif_ribbon_button_background_hover_filter', '#14a168' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_background_hover', array(
			'label' => __( 'BottomButton Ribbon - button background color hover', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 7,
		)));

		/* zerif_ribbon_button_button_color */
		$wp_customize->add_setting( 'zerif_ribbon_button_button_color', array(
			'default' => apply_filters( 'zerif_ribbon_button_button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 8,
		)));

		/* zerif_ribbon_button_button_color_hover */
		$wp_customize->add_setting( 'zerif_ribbon_button_button_color_hover', array(
			'default' => apply_filters( 'zerif_ribbon_button_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbon_button_button_color_hover', array(
			'label' => __( 'Button text color hover', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 9,
		)));

		/* RIBBON SECTION WITH BUTTON IN THE RIGHT SIDE */

		/* zerif_ribbonright_text */
		$wp_customize->add_setting( 'zerif_ribbonright_text', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_ribbonright_text', array(
			'label' => __( 'RightButton Ribbon - Main text', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 10,
		));

		/* zerif_ribbonright_buttonlabel */
		$wp_customize->add_setting( 'zerif_ribbonright_buttonlabel', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_ribbonright_buttonlabel', array(
			'label' => __( 'RightButton Ribbon - Button label', 'zerif' ),
			'description' => __( 'The button link must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 11,
		));

		/* zerif_ribbonright_buttonlink */
		$wp_customize->add_setting( 'zerif_ribbonright_buttonlink', array(
			'sanitize_callback' => 'esc_url_raw',
		));

		$wp_customize->add_control( 'zerif_ribbonright_buttonlink', array(
			'label' => __( 'RightButton Ribbon - Button link', 'zerif' ),
			'description' => __( 'The button label must be filled too, for the button to show up.', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 12,
		));

		/* zerif_ribbonright_background */
		$wp_customize->add_setting( 'zerif_ribbonright_background', array(
			'default' => apply_filters( 'zerif_ribbonright_background_filter', 'rgba(233, 102, 86, 1)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_ribbonright_background', array(
			'label' => __( 'RightButton Ribbon - section background', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_ribbon_section',
			'priority' => 13,
		)));

		/* zerif_ribbonright_text_color */
		$wp_customize->add_setting( 'zerif_ribbonright_text_color', array(
			'default' => apply_filters( 'zerif_ribbonright_text_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_text_color', array(
			'label' => __( 'RightButton Ribbon - color text', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 14,
		)));

		/* zerif_ribbonright_button_background */
		$wp_customize->add_setting( 'zerif_ribbonright_button_background', array(
			'default' => apply_filters( 'zerif_ribbonright_button_background_filter', '#db5a4a' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_background', array(
			'label' => __( 'RightButton Ribbon - button background color', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 15,
		)));

		/* zerif_ribbonright_button_background_hover */
		$wp_customize->add_setting( 'zerif_ribbonright_button_background_hover', array(
			'default' => apply_filters( 'zerif_ribbonright_button_background_hover_filter', '#bf3928' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_background_hover', array(
			'label' => __( 'RightButton Ribbon - button background color hover', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 16,
		)));

		/* zerif_ribbonright_button_button_color */
		$wp_customize->add_setting( 'zerif_ribbonright_button_button_color', array(
			'default' => apply_filters( 'zerif_ribbonright_button_button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 17,
		)));

		/* zerif_ribbonright_button_button_color_hover */
		$wp_customize->add_setting( 'zerif_ribbonright_button_button_color_hover', array(
			'default' => apply_filters( 'zerif_ribbonright_button_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_ribbonright_button_button_color_hover', array(
			'label' => __( 'Button text color hover', 'zerif' ),
			'section' => 'zerif_ribbon_section',
			'priority' => 18,
		)));

	}

	/**
	 * CONTACT US SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_10', array(
			'priority' => 39,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Contact us section', 'zerif' ),
		));

		/* CONTACT US SETTINGS */

		$zerif_pirate_forms_settings = '';
		if ( defined( 'PIRATE_FORMS_VERSION' ) ) {
			/* translators: Pirate Forms settings page */
			$zerif_pirate_forms_settings = '<div class="zerif-pirate-forms-settings"><p>' . sprintf( __( 'To have access to more customization options for the contact us section please visit the %s settings page.', 'zerif' ), sprintf( '<a href="' . esc_url( 'options-general.php?page=pirate-forms-admin' ) . '" target="_blank" >%s</a>', esc_html__( 'Pirate Forms', 'zerif' ) ) ) . '</p></div>';
		}

		$wp_customize->add_section( 'zerif_contactus_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'description' => $zerif_pirate_forms_settings,
			'priority' => 1,
			'panel' => 'panel_10',
		));

		/* zerif_contactus_show */
		$wp_customize->add_setting( 'zerif_contactus_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_contactus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide contact us section?', 'zerif' ),
			'description' => __( 'If you check this box, the Contact us section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_contactus_settings_section',
			'priority' => 1,
		));

		/* zerif_contactus_email */
		$wp_customize->add_setting( 'zerif_contactus_email', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_contactus_email', array(
			'label' => __( 'Email address', 'zerif' ),
			'description' => __( 'The contact us form is submitted to this email address.', 'zerif' ),
			'section' => 'zerif_contactus_settings_section',
			'priority' => 4,
		));

		/* zerif_contactus_recaptcha_show */
		$wp_customize->add_setting( 'zerif_contactus_recaptcha_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_contactus_recaptcha_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide reCaptcha?', 'zerif' ),
			'description' => __( 'If you check this box, the reCaptcha will not be enabled on the Contact us form.', 'zerif' ),
			'section' => 'zerif_contactus_settings_section',
			'priority' => 10,
		));

		/* zerif_contactus_sitekey */
		$wp_customize->add_setting( 'zerif_contactus_sitekey', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_contactus_sitekey', array(
			'label' => __( 'Site key', 'zerif' ),
			'description' => '<a href="https://www.google.com/recaptcha/admin#list" target="_blank">' . __( 'Create an account here', 'zerif' ) . '</a>' . __( ' to get the Site key and the Secret key for the reCaptcha.', 'zerif' ),
			'section' => 'zerif_contactus_settings_section',
			'priority' => 11,
		));

		/* zerif_contactus_secretkey */
		$wp_customize->add_setting( 'zerif_contactus_secretkey', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_contactus_secretkey', array(
			'label' => __( 'Secret key', 'zerif' ),
			'section' => 'zerif_contactus_settings_section',
			'priority' => 12,
		));

		/* CONTACT US MAIN CONTENT */

		$wp_customize->add_section( 'zerif_contactus_texts_section', array(
			'title' => __( 'Main content', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_10',
		));

		/* zerif_contactus_title */
		$wp_customize->add_setting( 'zerif_contactus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Get in touch', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 2,
		));

		/* zerif_contactus_subtitle */
		$wp_customize->add_setting( 'zerif_contactus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 3,
		));

		/* zerif_contactus_name_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_name_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Name', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_name_placeholder', array(
			'label' => __( 'Placeholder for "Your Name" input ', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 4,
		));

		/* zerif_contactus_email_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_email_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Email', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_email_placeholder', array(
			'label' => __( 'Placeholder for "Your Email" input', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 5,
		));

		/* zerif_contactus_subject_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_subject_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Subject', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_subject_placeholder', array(
			'label' => __( 'Placeholder for "Subject" input', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 6,
		));

		/* zerif_contactus_message_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_message_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Message', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_message_placeholder', array(
			'label' => __( 'Placeholder for "Message" input', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 7,
		));

		/* zerif_contactus_button_label */
		$wp_customize->add_setting( 'zerif_contactus_button_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Send Message', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_contactus_button_label', array(
			'label' => __( 'Send message button label', 'zerif' ),
			'section' => 'zerif_contactus_texts_section',
			'priority' => 8,
		));

		/* CONTACT US MAIN COLORS */

		$wp_customize->add_section( 'zerif_contactus_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_10',
		));

		/* zerif_contacus_background */
		$wp_customize->add_setting( 'zerif_contacus_background', array(
			'default' => apply_filters( 'zerif_contacus_background_filters', 'rgba(0, 0, 0, 0.5)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_contacus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_contactus_colors_section',
			'priority' => 1,
		)));

		/* zerif_contacus_header */
		$wp_customize->add_setting( 'zerif_contacus_header', array(
			'default' => apply_filters( 'zerif_contacus_header_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_header', array(
			'label' => __( 'Title and subtitle color', 'zerif' ),
			'section' => 'zerif_contactus_colors_section',
			'priority' => 2,
		)));

		/* zerif_contacus_button_background */
		$wp_customize->add_setting( 'zerif_contacus_button_background', array(
			'default' => apply_filters( 'zerif_contacus_button_background_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_background', array(
			'label' => __( 'Submit button background color', 'zerif' ),
			'section' => 'zerif_contactus_colors_section',
			'priority' => 3,
		)));

		/* zerif_contacus_button_background_hover */
		$wp_customize->add_setting( 'zerif_contacus_button_background_hover', array(
			'default' => apply_filters( 'zerif_contacus_button_background_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_background_hover', array(
			'label' => __( 'Submit button background color - hover', 'zerif' ),
			'section' => 'zerif_contactus_colors_section',
			'priority' => 4,
		)));

		/* zerif_contacus_button_color */
		$wp_customize->add_setting( 'zerif_contacus_button_color', array(
			'default' => apply_filters( 'zerif_contacus_button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_color', array(
			'label' => __( 'Submit button color', 'zerif' ),
			'section' => 'zerif_contactus_colors_section',
			'priority' => 5,
		)));

		/* zerif_contacus_button_color_hover */
		$wp_customize->add_setting( 'zerif_contacus_button_color_hover', array(
			'default' => apply_filters( 'zerif_contacus_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_color_hover', array(
			'label' => __( 'Submit button color - hover', 'zerif' ),
			'section' => 'zerif_contactus_colors_section',
			'priority' => 6,
		)));

	} else { /* For old versions of WordPress */

		$zerif_pirate_forms_settings = '';
		if ( defined( 'PIRATE_FORMS_VERSION' ) ) {
			/* translators: Pirate Forms settings page */
			$zerif_pirate_forms_settings = '<div class="zerif-pirate-forms-settings"><p>' . sprintf( __( 'To have access to more customization options for the contact us section please visit the %s settings page.', 'zerif' ), sprintf( '<a href="' . esc_url( 'options-general.php?page=pirate-forms-admin' ) . '" target="_blank" >%s</a>', esc_html__( 'Pirate Forms', 'zerif' ) ) ) . '</p></div>';
		}

		$wp_customize->add_section( 'zerif_contactus_section', array(
			'title' => __( 'Contact us section', 'zerif' ),
			'description' => $zerif_pirate_forms_settings,
			'priority' => 39,
		));

		/* zerif_contactus_show */
		$wp_customize->add_setting( 'zerif_contactus_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_contactus_show', array(
			'type' => 'checkbox',
			'label' => __( 'Hide contact us section?', 'zerif' ),
			'description' => __( 'If you check this box, the Contact us section will disappear from homepage.', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 1,
		));

		/* zerif_contactus_title */
		$wp_customize->add_setting( 'zerif_contactus_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Get in touch', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 2,
		));

		/* zerif_contactus_subtitle */
		$wp_customize->add_setting( 'zerif_contactus_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_contactus_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 3,
		));

		/* zerif_contactus_email */
		$wp_customize->add_setting( 'zerif_contactus_email', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_contactus_email', array(
			'label' => __( 'Email address', 'zerif' ),
			'description' => __( 'The contact us form is submitted to this email address.', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 4,
		));

		/* zerif_contactus_button_label */
		$wp_customize->add_setting( 'zerif_contactus_button_label', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Send Message', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_button_label', array(
			'label' => __( 'Send message button label', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 5,
		));

		/* zerif_contactus_name_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_name_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Name', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_name_placeholder', array(
			'label' => __( 'Placeholder for "Your Name" input ', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 6,
		));

		/* zerif_contactus_email_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_email_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Email', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_email_placeholder', array(
			'label' => __( 'Placeholder for "Your Email" input', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 7,
		));

		/* zerif_contactus_subject_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_subject_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Subject', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_subject_placeholder', array(
			'label' => __( 'Placeholder for "Subject" input', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 8,
		));

		/* zerif_contactus_message_placeholder */
		$wp_customize->add_setting( 'zerif_contactus_message_placeholder', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Your Message', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_contactus_message_placeholder', array(
			'label' => __( 'Placeholder for "Message" input', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 9,
		));

		/* zerif_contacus_background */
		$wp_customize->add_setting( 'zerif_contacus_background', array(
			'default' => apply_filters( 'zerif_contacus_background_filters', 'rgba(0, 0, 0, 0.5)' ),
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_contacus_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_contactus_section',
			'priority' => 10,
		)));

		/* zerif_contacus_header */
		$wp_customize->add_setting( 'zerif_contacus_header', array(
			'default' => apply_filters( 'zerif_contacus_header_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_header', array(
			'label' => __( 'Title and subtitle color', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 11,
		)));

		/* zerif_contacus_button_background */
		$wp_customize->add_setting( 'zerif_contacus_button_background', array(
			'default' => apply_filters( 'zerif_contacus_button_background_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_background', array(
			'label' => __( 'Submit button background color', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 12,
		)));

		/* zerif_contacus_button_background_hover */
		$wp_customize->add_setting( 'zerif_contacus_button_background_hover', array(
			'default' => apply_filters( 'zerif_contacus_button_background_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_background_hover', array(
			'label' => __( 'Submit button background color - hover', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 13,
		)));

		/* zerif_contacus_button_color */
		$wp_customize->add_setting( 'zerif_contacus_button_color', array(
			'default' => apply_filters( 'zerif_contacus_button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_color', array(
			'label' => __( 'Submit button color', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 14,
		)));

		/* zerif_contacus_button_color_hover */
		$wp_customize->add_setting( 'zerif_contacus_button_color_hover', array(
			'default' => apply_filters( 'zerif_contacus_button_color_hover_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_contacus_button_color_hover', array(
			'label' => __( 'Submit button color - hover', 'zerif' ),
			'section' => 'zerif_contactus_section',
			'priority' => 15,
		)));

	}

	/**
	 * PACKAGES SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_11', array(
			'priority'       => 40,
			'capability'     => 'edit_theme_options',
			'theme_supports' => '',
			'title'          => __( 'Packages section', 'zerif' ),
		) );

		/* PACKAGES SETTINGS */

		$wp_customize->add_section( 'zerif_packages_settings_section', array(
			'title'    => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel'    => 'panel_11',
		) );

		/* zerif_packages_show */
		$wp_customize->add_setting( 'zerif_packages_show', array(
			'transport'         => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'zerif_packages_show', array(
			'type'        => 'checkbox',
			'label'       => __( 'Show packages section?', 'zerif' ),
			'description' => __( 'If you check this box, the Packages section will appear on homepage.', 'zerif' ),
			'section'     => 'zerif_packages_settings_section',
			'priority'    => 1,
		) );

		/* PACKAGES HEADER */

		$wp_customize->add_section( 'zerif_packages_texts_section', array(
			'title'    => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel'    => 'panel_11',
		) );

		/* zerif_packages_title */
		$wp_customize->add_setting( 'zerif_packages_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default'           => __( 'PACKAGES', 'zerif' ),
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'zerif_packages_title', array(
			'label'    => __( 'Main title', 'zerif' ),
			'section'  => 'zerif_packages_texts_section',
			'priority' => 2,
		) );

		/* zerif_packages_subtitle */
		$wp_customize->add_setting( 'zerif_packages_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default'           => __( 'We have 4 friendly packages for you. Check all the packages and choose the right one for you.', 'zerif' ),
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'zerif_packages_subtitle', array(
			'label'    => __( 'Subtitle', 'zerif' ),
			'section'  => 'zerif_packages_texts_section',
			'priority' => 3,
		) );

		/* PACKAGES COLORS */

		$wp_customize->add_section( 'zerif_packages_colors_section', array(
			'title'    => __( 'Colors', 'zerif' ),
			'priority' => 4,
			'panel'    => 'panel_11',
		) );

		/* zerif_packages_background */
		$wp_customize->add_setting( 'zerif_packages_background', array(
			'default'           => apply_filters( 'zerif_packages_background_filter', 'rgba(0, 0, 0, 0.5)' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		) );

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_packages_background', array(
			'label'    => __( 'Background color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 1,
		) ) );

		/* zerif_packages_header */
		$wp_customize->add_setting( 'zerif_packages_header', array(
			'default'           => apply_filters( 'zerif_packages_header_filter', '#fff' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_packages_header', array(
			'label'    => __( 'Title and subtitle colors', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 2,
		) ) );

		/* zerif_package_title_color */
		$wp_customize->add_setting( 'zerif_package_title_color', array(
			'default'           => apply_filters( 'zerif_package_title_color_filter', '#fff' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_title_color', array(
			'label'    => __( 'Package title color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 3,
		) ) );

		/* zerif_package_text_color */
		$wp_customize->add_setting( 'zerif_package_text_color', array(
			'default'           => apply_filters( 'zerif_package_text_color_filter', '#808080' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_text_color', array(
			'label'    => __( 'Package text color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 4,
		) ) );

		/* zerif_package_button_text_color */
		$wp_customize->add_setting( 'zerif_package_button_text_color', array(
			'default'           => apply_filters( 'zerif_package_button_text_color_filter', '#fff' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_button_text_color', array(
			'label'    => __( 'Package button text color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 5,
		) ) );

		/* zerif_package_price_background_color */
		$wp_customize->add_setting( 'zerif_package_price_background_color', array(
			'default'           => apply_filters( 'zerif_package_price_background_color_filter', '#404040' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_price_background_color', array(
			'label'    => __( 'Package price background color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 6,
		) ) );

		/* zerif_package_price_color */
		$wp_customize->add_setting( 'zerif_package_price_color', array(
			'default'           => apply_filters( 'zerif_package_price_color_filter', '#fff' ),
			'transport'         => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_price_color', array(
			'label'    => __( 'Package price color', 'zerif' ),
			'section'  => 'zerif_packages_colors_section',
			'priority' => 7,
		) ) );

	} else { /* For old versions of WordPress */

		$wp_customize->add_section( 'zerif_packages_section', array(
			'title'    => __( 'Packages section', 'zerif' ),
			'priority' => 40,
		) );

		/* zerif_packages_show */
		$wp_customize->add_setting( 'zerif_packages_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		) );

		$wp_customize->add_control( 'zerif_packages_show', array(
			'type'        => 'checkbox',
			'label'       => __( 'Show packages section?', 'zerif' ),
			'description' => __( 'If you check this box, the Packages section will appear on homepage.', 'zerif' ),
			'section'     => 'zerif_packages_section',
			'priority'    => 1,
		) );

		/* zerif_packages_title */
		$wp_customize->add_setting( 'zerif_packages_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default'           => __( 'PACKAGES', 'zerif' ),
		) );

		$wp_customize->add_control( 'zerif_packages_title', array(
			'label'    => __( 'Main title', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 2,
		) );

		/* zerif_packages_subtitle */
		$wp_customize->add_setting( 'zerif_packages_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default'           => __( 'We have 4 friendly packages for you. Check all the packages and choose the right one for you.', 'zerif' ),
		) );

		$wp_customize->add_control( 'zerif_packages_subtitle', array(
			'label'    => __( 'Subtitle', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 3,
		) );

		/* zerif_packages_header */
		$wp_customize->add_setting( 'zerif_packages_header', array(
			'default'           => apply_filters( 'zerif_packages_header_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_packages_header', array(
			'label'    => __( 'Title and subtitle colors', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 4,
		) ) );

		/* zerif_package_title_color */
		$wp_customize->add_setting( 'zerif_package_title_color', array(
			'default'           => apply_filters( 'zerif_package_title_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_title_color', array(
			'label'    => __( 'Package title color', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 5,
		) ) );

		/* zerif_package_text_color */
		$wp_customize->add_setting( 'zerif_package_text_color', array(
			'default'           => apply_filters( 'zerif_package_text_color_filter', '#808080' ),
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_text_color', array(
			'label'    => __( 'Package text color', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 6,
		) ) );

		/* zerif_package_button_text_color */
		$wp_customize->add_setting( 'zerif_package_button_text_color', array(
			'default'           => '#fff',
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_button_text_color', array(
			'label'    => __( 'Package button text color', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 7,
		) ) );

		/* zerif_package_price_background_color */
		$wp_customize->add_setting( 'zerif_package_price_background_color', array(
			'default'           => apply_filters( 'zerif_package_price_background_color_filter', '#404040' ),
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_price_background_color', array(
			'label'    => __( 'Package price background color', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 8,
		) ) );

		/* zerif_package_price_color */
		$wp_customize->add_setting( 'zerif_package_price_color', array(
			'default'           => apply_filters( 'zerif_package_price_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		) );

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_package_price_color', array(
			'label'    => __( 'Package price color', 'zerif' ),
			'section'  => 'zerif_packages_section',
			'priority' => 9,
		) ) );

	}

	/**
	 * GOOGLE MAP SECTION
	 */

	$wp_customize->add_section( 'zerif_googlemap_section' , array(
		'title'       => __( 'Google map section', 'zerif' ),
		'priority'    => 41,
	));

	/* zerif_googlemap_show */
	$wp_customize->add_setting( 'zerif_googlemap_show', array(
		'sanitize_callback' => 'zerif_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'zerif_googlemap_show', array(
		'type' => 'checkbox',
		'label' => __( 'Show google map section?','zerif' ),
		'description' => __( 'If you check this box, the Google map section will appear on homepage.','zerif' ),
		'section' => 'zerif_googlemap_section',
		'priority'    => 1,
	) );

	/* zerif_googlemap_address */
	$wp_customize->add_setting( 'zerif_googlemap_address', array(
		'sanitize_callback' => 'zerif_sanitize_input',
		'default' => __( 'New York, Leroy Street','zerif' ),
	) );

	$wp_customize->add_control( 'zerif_googlemap_address', array(
		'label'    => __( 'Google map address', 'zerif' ),
		'section'  => 'zerif_googlemap_section',
		'priority'    => 2,
	));

	/* zerif_googlemap_static */
	$wp_customize->add_setting( 'zerif_googlemap_static', array(
		'sanitize_callback' => 'zerif_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'zerif_googlemap_static', array(
		'type' => 'checkbox',
		'label' => __( 'Show STATIC google map ?','zerif' ),
		'description' => __( 'If you check this box, the Google map section will display as a static google map.','zerif' ),
		'section' => 'zerif_googlemap_section',
		'priority'    => 3,
	) );

	if ( defined( 'INTERGEO_PLUGIN_NAME' ) ) {

		/* zerif_googlemap_shortcode */
		$wp_customize->add_setting( 'zerif_googlemap_shortcode', array(
			'sanitize_callback' => 'zerif_sanitize_input',
		));

		$wp_customize->add_control( 'zerif_googlemap_shortcode', array(
			'label' => __( 'Intergeo Shortcode', 'zerif' ),
			'section' => 'zerif_googlemap_section',
			'priority' => 4,
		));

	} else {

		$wp_customize->add_setting( 'zerif_googlemap_shortcode' );

		$wp_customize->add_control( new Zerif_Intergeo_Panel( $wp_customize, 'zerif_googlemap_shortcode', array(
			'section' => 'zerif_googlemap_section',
			'priority' => 4,
		)));

	}

	/**
	 * LATEST NEWS SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_14', array(
			'priority' => 42,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Latest news section', 'zerif' ),
		));

		/* LATEST NEWS SETTINGS */

		$wp_customize->add_section( 'zerif_latest_news_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_14',
		));

		/* zerif_latest_news_show */
		$wp_customize->add_setting( 'zerif_latest_news_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_latest_news_show', array(
			'type' => 'checkbox',
			'label' => __( 'Show latest news section?', 'zerif' ),
			'description' => __( 'If you check this box, the Latest news section will appear on homepage.', 'zerif' ),
			'section' => 'zerif_latest_news_settings_section',
			'priority' => 1,
		));

		/* LATEST NEWS HEADER */

		$wp_customize->add_section( 'zerif_latest_news_section', array(
			'title' => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_14',
		));

		/* zerif_latestnews_title */
		$wp_customize->add_setting( 'zerif_latestnews_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'LATEST NEWS', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_latestnews_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 1,
		));

		/* zerif_latestnews_subtitle */
		$wp_customize->add_setting( 'zerif_latestnews_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Latest news section"', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_latestnews_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 2,
		));

		/* LATEST NEWS CONTENT */

		$wp_customize->add_section( 'zerif_latest_news_content_section', array(
			'title' => __( 'Main content', 'zerif' ),
			'priority' => 3,
			'panel' => 'panel_14',
		));

		$wp_customize->add_setting( 'zerif_latest_news_content_section' );

		$wp_customize->add_control( new Zerif_LatestNews( $wp_customize, 'zerif_latest_news_content_section', array(
			'section' => 'zerif_latest_news_content_section',
		)));

		/* LATEST NEWS COLORS */

		$wp_customize->add_section( 'zerif_latest_news_colors_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_14',
		));

		/* zerif_latestnews_background */
		$wp_customize->add_setting( 'zerif_latestnews_background', array(
			'default' => apply_filters( 'zerif_latestnews_background_filter', 'rgba(255, 255, 255, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_latestnews_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 1,
		)));

		/* zerif_latestnews_header_title_color */
		$wp_customize->add_setting( 'zerif_latestnews_header_title_color', array(
			'default' => apply_filters( 'zerif_latestnews_header_title_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_header_title_color', array(
			'label' => __( 'Title color', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 2,
		)));

		/* zerif_latestnews_header_subtitle_color */
		$wp_customize->add_setting( 'zerif_latestnews_header_subtitle_color', array(
			'default' => apply_filters( 'zerif_latestnews_header_subtitle_color_filter', '#808080' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_header_subtitle_color', array(
			'label' => __( 'Subtitle color', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 3,
		)));

		/* zerif_latestnews_post_title_color */
		$wp_customize->add_setting( 'zerif_latestnews_post_title_color', array(
			'default' => apply_filters( 'zerif_latestnews_post_title_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_title_color', array(
			'label' => __( 'Post title color', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 4,
		)));

		/* zerif_latestnews_post_underline_color1 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color1', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color1_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color1', array(
			'label' => __( 'Post title underline color - first box', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 5,
		)));

		/* zerif_latestnews_post_underline_color2 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color2', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color2_filter', '#34d293' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color2', array(
			'label' => __( 'Post title underline color - second box', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 6,
		)));

		/* zerif_latestnews_post_underline_color3 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color3', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color3_filter', '#3ab0e2' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color3', array(
			'label' => __( 'Post title underline color - third box', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 7,
		)));

		/* zerif_latestnews_post_underline_color4 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color4', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color4_filter', '#f7d861' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color4', array(
			'label' => __( 'Post title underline color - fourth box', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 8,
		)));

		/* zerif_latestnews_post_text_color */
		$wp_customize->add_setting( 'zerif_latestnews_post_text_color', array(
			'default' => apply_filters( 'zerif_latestnews_post_text_color_filter', '#909090' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_text_color', array(
			'label' => __( 'Post content color', 'zerif' ),
			'section' => 'zerif_latest_news_colors_section',
			'priority' => 9,
		)));

	} else { /* Older versions of WordPress */

		$wp_customize->add_section( 'zerif_latest_news_section', array(
			'title' => __( 'Latest news section', 'zerif' ),
			'priority' => 42,
		));

		/* zerif_latest_news_show */
		$wp_customize->add_setting( 'zerif_latest_news_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_latest_news_show', array(
			'type' => 'checkbox',
			'label' => __( 'Show latest news section?', 'zerif' ),
			'description' => __( 'If you check this box, the Latest news section will appear on homepage.', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 1,
		));

		/* zerif_latestnews_title */
		$wp_customize->add_setting( 'zerif_latestnews_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'LATEST NEWS', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_latestnews_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 2,
		));

		/* zerif_latestnews_subtitle */
		$wp_customize->add_setting( 'zerif_latestnews_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Add a subtitle in Customizer, "Latest news section"', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_latestnews_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 3,
		));

		/* zerif_latestnews_background */
		$wp_customize->add_setting( 'zerif_latestnews_background', array(
			'default' => apply_filters( 'zerif_latestnews_background_filter', 'rgba(255, 255, 255, 1)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_latestnews_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'palette' => true,
			'section' => 'zerif_latest_news_section',
			'priority' => 4,
		)));

		/* zerif_latestnews_header_title_color */
		$wp_customize->add_setting( 'zerif_latestnews_header_title_color', array(
			'default' => apply_filters( 'zerif_latestnews_header_title_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_header_title_color', array(
			'label' => __( 'Title color', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 5,
		)));

		/* zerif_latestnews_header_subtitle_color */
		$wp_customize->add_setting( 'zerif_latestnews_header_subtitle_color', array(
			'default' => apply_filters( 'zerif_latestnews_header_subtitle_color_filter', '#808080' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_header_subtitle_color', array(
			'label' => __( 'Subtitle color', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 6,
		)));

		/* zerif_latestnews_post_title_color */
		$wp_customize->add_setting( 'zerif_latestnews_post_title_color', array(
			'default' => apply_filters( 'zerif_latestnews_post_title_color_filter', '#404040' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_title_color', array(
			'label' => __( 'Post title color', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 7,
		)));

		/* zerif_latestnews_post_underline_color1 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color1', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color1_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color1', array(
			'label' => __( 'Post title underline color - first box', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 8,
		)));

		/* zerif_latestnews_post_underline_color2 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color2', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color2_filter', '#34d293' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color2', array(
			'label' => __( 'Post title underline color - second box', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 9,
		)));

		/* zerif_latestnews_post_underline_color3 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color3', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color3_filter', '#3ab0e2' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color3', array(
			'label' => __( 'Post title underline color - third box', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 10,
		)));

		/* zerif_latestnews_post_underline_color4 */
		$wp_customize->add_setting( 'zerif_latestnews_post_underline_color4', array(
			'default' => apply_filters( 'zerif_latestnews_post_underline_color4_filter', '#f7d861' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_underline_color4', array(
			'label' => __( 'Post title underline color - fourth box', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 11,
		)));

		/* zerif_latestnews_post_text_color */
		$wp_customize->add_setting( 'zerif_latestnews_post_text_color', array(
			'default' => apply_filters( 'zerif_latestnews_post_text_color_filter', '#909090' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_latestnews_post_text_color', array(
			'label' => __( 'Post content color', 'zerif' ),
			'section' => 'zerif_latest_news_section',
			'priority' => 12,
		)));

	}

	/**
	 * SUBSCRIBE SECTION
	 */

	if ( class_exists( 'WP_Customize_Panel' ) ) {

		$wp_customize->add_panel( 'panel_13', array(
			'priority' => 43,
			'capability' => 'edit_theme_options',
			'theme_supports' => '',
			'title' => __( 'Subscribe section', 'zerif' ),
		));

		/* SUBSCRIBE SETTINGS */

		$wp_customize->add_section( 'zerif_subscribe_settings_section', array(
			'title' => __( 'Settings', 'zerif' ),
			'priority' => 1,
			'panel' => 'panel_13',
		));

		/* zerif_subscribe_show */
		$wp_customize->add_setting( 'zerif_subscribe_show', array(
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_subscribe_show', array(
			'type' => 'checkbox',
			'label' => __( 'Show subscribe section?', 'zerif' ),
			'description' => __( 'If you check this box, the Subscribe section will appear on homepage.', 'zerif' ),
			'section' => 'zerif_subscribe_settings_section',
			'priority' => 1,
		));

		/* SUBSCRIBE HEADER */

		$wp_customize->add_section( 'zerif_subscribe_section', array(
			'title' => __( 'Header', 'zerif' ),
			'priority' => 2,
			'panel' => 'panel_13',
		));

		/* zerif_subscribe_title */
		$wp_customize->add_setting( 'zerif_subscribe_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'STAY IN TOUCH', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_subscribe_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 1,
		));

		/* zerif_subscribe_subtitle */
		$wp_customize->add_setting( 'zerif_subscribe_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Sign Up for Email Updates on on News & Offers', 'zerif' ),
			'transport' => 'postMessage',
		));

		$wp_customize->add_control( 'zerif_subscribe_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 2,
		));

		/* SUBSCRIBE COLORS */

		$wp_customize->add_section( 'zerif_subscribe_color_section', array(
			'title' => __( 'Colors', 'zerif' ),
			'priority' => 4,
			'panel' => 'panel_13',
		));

		/* zerif_subscribe_background */
		$wp_customize->add_setting( 'zerif_subscribe_background', array(
			'default' => apply_filters( 'zerif_subscribe_background_filter', 'rgba(0, 0, 0, 0.5)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_subscribe_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'section' => 'zerif_subscribe_color_section',
			'priority' => 1,
		)));

		/* zerif_subscribe_header_color */
		$wp_customize->add_setting( 'zerif_subscribe_header_color', array(
			'default' => apply_filters( 'zerif_subscribe_header_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_header_color', array(
			'label' => __( 'Title and subtitle colors', 'zerif' ),
			'section' => 'zerif_subscribe_color_section',
			'priority' => 2,
		)));

		/* zerif_subscribe_button_background_color */
		$wp_customize->add_setting( 'zerif_subscribe_button_background_color', array(
			'default' => apply_filters( 'zerif_subscribe_button_background_color_filter', '#e96656' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_background_color', array(
			'label' => __( 'Button background color', 'zerif' ),
			'section' => 'zerif_subscribe_color_section',
			'priority' => 3,
		)));

		/* zerif_subscribe_button_background_color_hover */
		$wp_customize->add_setting( 'zerif_subscribe_button_background_color_hover', array(
			'default' => apply_filters( 'zerif_subscribe_button_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_background_color_hover', array(
			'label' => __( 'Button background color - hover', 'zerif' ),
			'section' => 'zerif_subscribe_color_section',
			'priority' => 4,
		)));

		/* zerif_subscribe_button_color */
		$wp_customize->add_setting( 'zerif_subscribe_button_color', array(
			'default' => apply_filters( 'zerif_subscribe_button_color_filter', '#fff' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_subscribe_color_section',
			'priority' => 5,
		)));

	} else { /* Old versions of WordPress */

		$wp_customize->add_section( 'zerif_subscribe_section', array(
			'title' => __( 'Subscribe section', 'zerif' ),
			'priority' => 43,
			'description' => __( 'For this section to work properly, you must add the "SendinBlue Widget" to the "Subscribe section" widgets area', 'zerif' ),
		));

		/* zerif_subscribe_show */
		$wp_customize->add_setting( 'zerif_subscribe_show', array(
			'sanitize_callback' => 'zerif_sanitize_checkbox',
		));

		$wp_customize->add_control( 'zerif_subscribe_show', array(
			'type' => 'checkbox',
			'label' => __( 'Show subscribe section?', 'zerif' ),
			'description' => __( 'If you check this box, the Subscribe section will appear on homepage.', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 1,
		));

		/* zerif_subscribe_title */
		$wp_customize->add_setting( 'zerif_subscribe_title', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'STAY IN TOUCH', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_subscribe_title', array(
			'label' => __( 'Main title', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 2,
		));

		/* zerif_subscribe_subtitle */
		$wp_customize->add_setting( 'zerif_subscribe_subtitle', array(
			'sanitize_callback' => 'zerif_sanitize_input',
			'default' => __( 'Sign Up for Email Updates on on News & Offers', 'zerif' ),
		));

		$wp_customize->add_control( 'zerif_subscribe_subtitle', array(
			'label' => __( 'Subtitle', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 3,
		));

		/* zerif_subscribe_background */
		$wp_customize->add_setting( 'zerif_subscribe_background', array(
			'default' => apply_filters( 'zerif_subscribe_background_filter', 'rgba(0, 0, 0, 0.5)' ),
			'transport' => 'postMessage',
			'sanitize_callback' => 'zerif_sanitize_rgba',
		));

		$wp_customize->add_control( new Zerif_Customize_Alpha_Color_Control( $wp_customize, 'zerif_subscribe_background', array(
			'label' => __( 'Background color', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 4,
		)));

		/* zerif_subscribe_header_color */
		$wp_customize->add_setting( 'zerif_subscribe_header_color', array(
			'default' => apply_filters( 'zerif_subscribe_header_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_header_color', array(
			'label' => __( 'Title and subtitle colors', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 5,
		)));

		/* zerif_subscribe_button_background_color */
		$wp_customize->add_setting( 'zerif_subscribe_button_background_color', array(
			'default' => apply_filters( 'zerif_subscribe_button_background_color_filter', '#e96656' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_background_color', array(
			'label' => __( 'Button background color', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 6,
		)));

		/* zerif_subscribe_button_background_color_hover */
		$wp_customize->add_setting( 'zerif_subscribe_button_background_color_hover', array(
			'default' => apply_filters( 'zerif_subscribe_button_background_color_hover_filter', '#cb4332' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_background_color_hover', array(
			'label' => __( 'Button background color - hover', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 7,
		)));

		/* zerif_subscribe_button_color */
		$wp_customize->add_setting( 'zerif_subscribe_button_color', array(
			'default' => apply_filters( 'zerif_subscribe_button_color_filter', '#fff' ),
			'sanitize_callback' => 'sanitize_hex_color',
		));

		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'zerif_subscribe_button_color', array(
			'label' => __( 'Button text color', 'zerif' ),
			'section' => 'zerif_subscribe_section',
			'priority' => 8,
		)));
	}
}

add_action( 'customize_register', 'wp_themeisle_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function wp_themeisle_customize_preview_js() {
	wp_enqueue_script( 'wp_themeisle_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '1.0.2', true );
	wp_localize_script( 'wp_themeisle_customizer', 'requestpost', array(
		'ajaxurl' => admin_url( 'admin-ajax.php' ),
	) );
}

add_action( 'customize_preview_init', 'wp_themeisle_customize_preview_js' );

/**
 * Sanitize section name
 *
 * @param string $input Input to be sanitized.
 */
function zerif_sanitize_section_name( $input ) {
	$zerif_posible_sections = array(
		'our_focus',
		'bottom_ribbon',
		'portofolio',
		'about_us',
		'our_team',
		'testimonials',
		'right_ribbon',
		'contact_us',
		'map',
		'packages',
		'subscribe',
		'latest_news',
		'shortcodes',
	);
	if ( in_array( $input, $zerif_posible_sections ) ) {
		return $input;
	}
	return $zerif_posible_sections[0];
}

/**
 * Sanitize repeater
 *
 * @param json $input Input to be sanitized.
 */
function zerif_sanitize_repeater( $input ) {
	$input_decoded = json_decode( $input,true );
	if ( ! empty( $input_decoded ) ) {
		foreach ( $input_decoded as $boxk => $box ) {
			foreach ( $box as $key => $value ) {
				if ( $key == 'text_color' || $key == 'color' ) {
					$value                          = html_entity_decode( $value );
					$input_decoded[ $boxk ][ $key ] = sanitize_hex_color( $value );
				} elseif ( $key == 'opacity' ) {
					$input_decoded[ $boxk ][ $key ] = ( is_numeric( $value ) ? $value : 1 );
				} else {
					$input_decoded[ $boxk ][ $key ] = wp_kses_post( force_balance_tags( $value ) );
				}
			}
		}
		return json_encode( $input_decoded );
	}
	return $input;
}

/**
 * Sanitize position
 *
 * @param string $input Input to be sanitized.
 */
function zerif_sanitize_position( $input ) {
	$zerif_posible_positions = array(
		'top',
		'center',
		'bottom',
	);
	if ( in_array( $input, $zerif_posible_positions ) ) {
		return $input;
	}
	return $zerif_posible_positions[0];
}

/**
 * Sanitize background size
 *
 * @param string $input Input to be sanitized.
 */
function zerif_sanitize_background_size( $input ) {
	$zerif_posible_sizes = array(
		'cover',
		'width',
		'height',
	);
	if ( in_array( $input, $zerif_posible_sizes ) ) {
		return $input;
	}
	return $zerif_posible_sizes[0];
}

/**
 * Sanitize horizontal alignment
 *
 * @param string $input Input to be sanitized.
 */
function zerif_sanitize_horizontal( $input ) {
	$zerif_posible_positions = array(
		'left',
		'center',
		'right',
	);
	if ( in_array( $input, $zerif_posible_positions ) ) {
		return $input;
	}
	return $zerif_posible_positions[0];
}

/**
 * Sanitize background type
 *
 * @param string $input Input to be sanitized.
 */
function zerif_sanitize_background_type( $input ) {
	$zerif_posible_types = array(
		'zerif-background-image',
		'zerif-background-slider',
		'zerif-background-video',
	);
	if ( in_array( $input, $zerif_posible_types ) ) {
		return $input;
	}
	return $zerif_posible_types[0];
}

/**
 * Sanitize checkboxes
 *
 * @param book $input Input to be sanitized.
 *
 * @return bool
 */
function zerif_sanitize_checkbox( $input ) {
	return ( isset( $input ) && true == $input ? true : false );
}

/**
 * Sanitize texts
 *
 * @param string $input Text to be sanitized.
 */
function zerif_sanitize_input( $input ) {
	return wp_kses_post( force_balance_tags( $input ) );
}

/**
 * Sanitize RGBA colors
 */
function zerif_sanitize_rgba( $value ) {

	// If empty or an array return transparent
	if ( empty( $value ) ) {
		return false;
	}
	$value = str_replace( ' ', '', $value );
	if ( substr( $value, 0, 4 ) == 'rgba' ) {
		sscanf( $value, 'rgba(%d,%d,%d,%f)', $red, $green, $blue, $alpha );
		return 'rgba(' . $red . ',' . $green . ',' . $blue . ',' . $alpha . ')';
	}
	return sanitize_hex_color( $value );
}

/**
 * Enqueue customizer script
 */
function zerif_registers() {
	wp_enqueue_script( 'zerif_customizer_script', get_template_directory_uri() . '/js/zerif_customizer.js', array( 'jquery', 'jquery-ui-core', 'jquery-ui-draggable' ), '20120206', true );
}

add_action( 'customize_controls_enqueue_scripts', 'zerif_registers' );
